# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ColumnDefinitionOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_name': 'str',
        'column_order': 'int',
        'column_type': 'str',
        'column_uom': 'str',
        'description': 'str',
        'display_property': 'str',
        'id': 'str',
        'is_generated': 'bool',
        'is_hidden': 'bool',
        'is_indexed': 'bool',
        'rules': 'list[ColumnRuleOutputV1]',
        'sort_ascending': 'bool',
        'sort_index': 'int'
    }

    attribute_map = {
        'column_name': 'columnName',
        'column_order': 'columnOrder',
        'column_type': 'columnType',
        'column_uom': 'columnUom',
        'description': 'description',
        'display_property': 'displayProperty',
        'id': 'id',
        'is_generated': 'isGenerated',
        'is_hidden': 'isHidden',
        'is_indexed': 'isIndexed',
        'rules': 'rules',
        'sort_ascending': 'sortAscending',
        'sort_index': 'sortIndex'
    }

    def __init__(self, column_name=None, column_order=None, column_type=None, column_uom=None, description=None, display_property=None, id=None, is_generated=None, is_hidden=None, is_indexed=None, rules=None, sort_ascending=None, sort_index=None):
        """
        ColumnDefinitionOutputV1 - a model defined in Swagger
        """

        self._column_name = None
        self._column_order = None
        self._column_type = None
        self._column_uom = None
        self._description = None
        self._display_property = None
        self._id = None
        self._is_generated = None
        self._is_hidden = None
        self._is_indexed = None
        self._rules = None
        self._sort_ascending = None
        self._sort_index = None

        if column_name is not None:
          self.column_name = column_name
        if column_order is not None:
          self.column_order = column_order
        if column_type is not None:
          self.column_type = column_type
        if column_uom is not None:
          self.column_uom = column_uom
        if description is not None:
          self.description = description
        if display_property is not None:
          self.display_property = display_property
        if id is not None:
          self.id = id
        if is_generated is not None:
          self.is_generated = is_generated
        if is_hidden is not None:
          self.is_hidden = is_hidden
        if is_indexed is not None:
          self.is_indexed = is_indexed
        if rules is not None:
          self.rules = rules
        if sort_ascending is not None:
          self.sort_ascending = sort_ascending
        if sort_index is not None:
          self.sort_index = sort_index

    @property
    def column_name(self):
        """
        Gets the column_name of this ColumnDefinitionOutputV1.
        The column definition's name

        :return: The column_name of this ColumnDefinitionOutputV1.
        :rtype: str
        """
        return self._column_name

    @column_name.setter
    def column_name(self, column_name):
        """
        Sets the column_name of this ColumnDefinitionOutputV1.
        The column definition's name

        :param column_name: The column_name of this ColumnDefinitionOutputV1.
        :type: str
        """
        if column_name is None:
            raise ValueError("Invalid value for `column_name`, must not be `None`")

        self._column_name = column_name

    @property
    def column_order(self):
        """
        Gets the column_order of this ColumnDefinitionOutputV1.
        1-based index representing the position of the column in the table

        :return: The column_order of this ColumnDefinitionOutputV1.
        :rtype: int
        """
        return self._column_order

    @column_order.setter
    def column_order(self, column_order):
        """
        Sets the column_order of this ColumnDefinitionOutputV1.
        1-based index representing the position of the column in the table

        :param column_order: The column_order of this ColumnDefinitionOutputV1.
        :type: int
        """

        self._column_order = column_order

    @property
    def column_type(self):
        """
        Gets the column_type of this ColumnDefinitionOutputV1.
        The type of the column being defined

        :return: The column_type of this ColumnDefinitionOutputV1.
        :rtype: str
        """
        return self._column_type

    @column_type.setter
    def column_type(self, column_type):
        """
        Sets the column_type of this ColumnDefinitionOutputV1.
        The type of the column being defined

        :param column_type: The column_type of this ColumnDefinitionOutputV1.
        :type: str
        """
        if column_type is None:
            raise ValueError("Invalid value for `column_type`, must not be `None`")

        self._column_type = column_type

    @property
    def column_uom(self):
        """
        Gets the column_uom of this ColumnDefinitionOutputV1.
        The column definition's Unit of Measure

        :return: The column_uom of this ColumnDefinitionOutputV1.
        :rtype: str
        """
        return self._column_uom

    @column_uom.setter
    def column_uom(self, column_uom):
        """
        Sets the column_uom of this ColumnDefinitionOutputV1.
        The column definition's Unit of Measure

        :param column_uom: The column_uom of this ColumnDefinitionOutputV1.
        :type: str
        """

        self._column_uom = column_uom

    @property
    def description(self):
        """
        Gets the description of this ColumnDefinitionOutputV1.
        The column definition's optional description

        :return: The description of this ColumnDefinitionOutputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ColumnDefinitionOutputV1.
        The column definition's optional description

        :param description: The description of this ColumnDefinitionOutputV1.
        :type: str
        """

        self._description = description

    @property
    def display_property(self):
        """
        Gets the display_property of this ColumnDefinitionOutputV1.
        The column definition's optional display property

        :return: The display_property of this ColumnDefinitionOutputV1.
        :rtype: str
        """
        return self._display_property

    @display_property.setter
    def display_property(self, display_property):
        """
        Sets the display_property of this ColumnDefinitionOutputV1.
        The column definition's optional display property

        :param display_property: The display_property of this ColumnDefinitionOutputV1.
        :type: str
        """

        self._display_property = display_property

    @property
    def id(self):
        """
        Gets the id of this ColumnDefinitionOutputV1.
        The column definition's ID

        :return: The id of this ColumnDefinitionOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ColumnDefinitionOutputV1.
        The column definition's ID

        :param id: The id of this ColumnDefinitionOutputV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def is_generated(self):
        """
        Gets the is_generated of this ColumnDefinitionOutputV1.
        Whether the column is generated by Seeq rather than user created

        :return: The is_generated of this ColumnDefinitionOutputV1.
        :rtype: bool
        """
        return self._is_generated

    @is_generated.setter
    def is_generated(self, is_generated):
        """
        Sets the is_generated of this ColumnDefinitionOutputV1.
        Whether the column is generated by Seeq rather than user created

        :param is_generated: The is_generated of this ColumnDefinitionOutputV1.
        :type: bool
        """
        if is_generated is None:
            raise ValueError("Invalid value for `is_generated`, must not be `None`")

        self._is_generated = is_generated

    @property
    def is_hidden(self):
        """
        Gets the is_hidden of this ColumnDefinitionOutputV1.
        Whether the column is hidden

        :return: The is_hidden of this ColumnDefinitionOutputV1.
        :rtype: bool
        """
        return self._is_hidden

    @is_hidden.setter
    def is_hidden(self, is_hidden):
        """
        Sets the is_hidden of this ColumnDefinitionOutputV1.
        Whether the column is hidden

        :param is_hidden: The is_hidden of this ColumnDefinitionOutputV1.
        :type: bool
        """
        if is_hidden is None:
            raise ValueError("Invalid value for `is_hidden`, must not be `None`")

        self._is_hidden = is_hidden

    @property
    def is_indexed(self):
        """
        Gets the is_indexed of this ColumnDefinitionOutputV1.
        Whether the column is indexed

        :return: The is_indexed of this ColumnDefinitionOutputV1.
        :rtype: bool
        """
        return self._is_indexed

    @is_indexed.setter
    def is_indexed(self, is_indexed):
        """
        Sets the is_indexed of this ColumnDefinitionOutputV1.
        Whether the column is indexed

        :param is_indexed: The is_indexed of this ColumnDefinitionOutputV1.
        :type: bool
        """
        if is_indexed is None:
            raise ValueError("Invalid value for `is_indexed`, must not be `None`")

        self._is_indexed = is_indexed

    @property
    def rules(self):
        """
        Gets the rules of this ColumnDefinitionOutputV1.
        The rules associated with the column definition

        :return: The rules of this ColumnDefinitionOutputV1.
        :rtype: list[ColumnRuleOutputV1]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """
        Sets the rules of this ColumnDefinitionOutputV1.
        The rules associated with the column definition

        :param rules: The rules of this ColumnDefinitionOutputV1.
        :type: list[ColumnRuleOutputV1]
        """
        if rules is None:
            raise ValueError("Invalid value for `rules`, must not be `None`")

        self._rules = rules

    @property
    def sort_ascending(self):
        """
        Gets the sort_ascending of this ColumnDefinitionOutputV1.
        Whether to sort ascending

        :return: The sort_ascending of this ColumnDefinitionOutputV1.
        :rtype: bool
        """
        return self._sort_ascending

    @sort_ascending.setter
    def sort_ascending(self, sort_ascending):
        """
        Sets the sort_ascending of this ColumnDefinitionOutputV1.
        Whether to sort ascending

        :param sort_ascending: The sort_ascending of this ColumnDefinitionOutputV1.
        :type: bool
        """
        if sort_ascending is None:
            raise ValueError("Invalid value for `sort_ascending`, must not be `None`")

        self._sort_ascending = sort_ascending

    @property
    def sort_index(self):
        """
        Gets the sort_index of this ColumnDefinitionOutputV1.
        The sort index for the column, null if not sorted

        :return: The sort_index of this ColumnDefinitionOutputV1.
        :rtype: int
        """
        return self._sort_index

    @sort_index.setter
    def sort_index(self, sort_index):
        """
        Sets the sort_index of this ColumnDefinitionOutputV1.
        The sort index for the column, null if not sorted

        :param sort_index: The sort_index of this ColumnDefinitionOutputV1.
        :type: int
        """

        self._sort_index = sort_index

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ColumnDefinitionOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class PluginOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'category': 'str',
        'description': 'str',
        'effective_permissions': 'PermissionsV1',
        'entry_point': 'str',
        'host': 'object',
        'icon': 'str',
        'id': 'str',
        'identifier': 'str',
        'in_development': 'bool',
        'installer': 'IdentityPreviewV1',
        'is_archived': 'bool',
        'is_redacted': 'bool',
        'name': 'str',
        'options': 'object',
        'status_message': 'str',
        'translation_key': 'str',
        'type': 'str',
        'version': 'str'
    }

    attribute_map = {
        'category': 'category',
        'description': 'description',
        'effective_permissions': 'effectivePermissions',
        'entry_point': 'entryPoint',
        'host': 'host',
        'icon': 'icon',
        'id': 'id',
        'identifier': 'identifier',
        'in_development': 'inDevelopment',
        'installer': 'installer',
        'is_archived': 'isArchived',
        'is_redacted': 'isRedacted',
        'name': 'name',
        'options': 'options',
        'status_message': 'statusMessage',
        'translation_key': 'translationKey',
        'type': 'type',
        'version': 'version'
    }

    def __init__(self, category=None, description=None, effective_permissions=None, entry_point=None, host=None, icon=None, id=None, identifier=None, in_development=None, installer=None, is_archived=False, is_redacted=False, name=None, options=None, status_message=None, translation_key=None, type=None, version=None):
        """
        PluginOutputV1 - a model defined in Swagger
        """

        self._category = None
        self._description = None
        self._effective_permissions = None
        self._entry_point = None
        self._host = None
        self._icon = None
        self._id = None
        self._identifier = None
        self._in_development = None
        self._installer = None
        self._is_archived = None
        self._is_redacted = None
        self._name = None
        self._options = None
        self._status_message = None
        self._translation_key = None
        self._type = None
        self._version = None

        if category is not None:
          self.category = category
        if description is not None:
          self.description = description
        if effective_permissions is not None:
          self.effective_permissions = effective_permissions
        if entry_point is not None:
          self.entry_point = entry_point
        if host is not None:
          self.host = host
        if icon is not None:
          self.icon = icon
        if id is not None:
          self.id = id
        if identifier is not None:
          self.identifier = identifier
        if in_development is not None:
          self.in_development = in_development
        if installer is not None:
          self.installer = installer
        if is_archived is not None:
          self.is_archived = is_archived
        if is_redacted is not None:
          self.is_redacted = is_redacted
        if name is not None:
          self.name = name
        if options is not None:
          self.options = options
        if status_message is not None:
          self.status_message = status_message
        if translation_key is not None:
          self.translation_key = translation_key
        if type is not None:
          self.type = type
        if version is not None:
          self.version = version

    @property
    def category(self):
        """
        Gets the category of this PluginOutputV1.
        The plugin category (e.g. \"DisplayPane\", \"ToolPane\")

        :return: The category of this PluginOutputV1.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this PluginOutputV1.
        The plugin category (e.g. \"DisplayPane\", \"ToolPane\")

        :param category: The category of this PluginOutputV1.
        :type: str
        """

        self._category = category

    @property
    def description(self):
        """
        Gets the description of this PluginOutputV1.
        Clarifying information or other plain language description of this item

        :return: The description of this PluginOutputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this PluginOutputV1.
        Clarifying information or other plain language description of this item

        :param description: The description of this PluginOutputV1.
        :type: str
        """

        self._description = description

    @property
    def effective_permissions(self):
        """
        Gets the effective_permissions of this PluginOutputV1.

        :return: The effective_permissions of this PluginOutputV1.
        :rtype: PermissionsV1
        """
        return self._effective_permissions

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions):
        """
        Sets the effective_permissions of this PluginOutputV1.

        :param effective_permissions: The effective_permissions of this PluginOutputV1.
        :type: PermissionsV1
        """

        self._effective_permissions = effective_permissions

    @property
    def entry_point(self):
        """
        Gets the entry_point of this PluginOutputV1.
        The relative path to the plugin entry point (e.g. \"myfolder/index.html \")

        :return: The entry_point of this PluginOutputV1.
        :rtype: str
        """
        return self._entry_point

    @entry_point.setter
    def entry_point(self, entry_point):
        """
        Sets the entry_point of this PluginOutputV1.
        The relative path to the plugin entry point (e.g. \"myfolder/index.html \")

        :param entry_point: The entry_point of this PluginOutputV1.
        :type: str
        """

        self._entry_point = entry_point

    @property
    def host(self):
        """
        Gets the host of this PluginOutputV1.
        Plugin host configuration settings

        :return: The host of this PluginOutputV1.
        :rtype: object
        """
        return self._host

    @host.setter
    def host(self, host):
        """
        Sets the host of this PluginOutputV1.
        Plugin host configuration settings

        :param host: The host of this PluginOutputV1.
        :type: object
        """

        self._host = host

    @property
    def icon(self):
        """
        Gets the icon of this PluginOutputV1.
        The plugin icon (e.g. \"fa fa-wrench\")

        :return: The icon of this PluginOutputV1.
        :rtype: str
        """
        return self._icon

    @icon.setter
    def icon(self, icon):
        """
        Sets the icon of this PluginOutputV1.
        The plugin icon (e.g. \"fa fa-wrench\")

        :param icon: The icon of this PluginOutputV1.
        :type: str
        """

        self._icon = icon

    @property
    def id(self):
        """
        Gets the id of this PluginOutputV1.
        The ID that can be used to interact with the item

        :return: The id of this PluginOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this PluginOutputV1.
        The ID that can be used to interact with the item

        :param id: The id of this PluginOutputV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def identifier(self):
        """
        Gets the identifier of this PluginOutputV1.
        The plugin identifier (e.g. \"com.seeq.samplePlugin\")

        :return: The identifier of this PluginOutputV1.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this PluginOutputV1.
        The plugin identifier (e.g. \"com.seeq.samplePlugin\")

        :param identifier: The identifier of this PluginOutputV1.
        :type: str
        """

        self._identifier = identifier

    @property
    def in_development(self):
        """
        Gets the in_development of this PluginOutputV1.
        Whether this item is in Development Mode, meaning that it is not allowed to be shared with any other users

        :return: The in_development of this PluginOutputV1.
        :rtype: bool
        """
        return self._in_development

    @in_development.setter
    def in_development(self, in_development):
        """
        Sets the in_development of this PluginOutputV1.
        Whether this item is in Development Mode, meaning that it is not allowed to be shared with any other users

        :param in_development: The in_development of this PluginOutputV1.
        :type: bool
        """

        self._in_development = in_development

    @property
    def installer(self):
        """
        Gets the installer of this PluginOutputV1.

        :return: The installer of this PluginOutputV1.
        :rtype: IdentityPreviewV1
        """
        return self._installer

    @installer.setter
    def installer(self, installer):
        """
        Sets the installer of this PluginOutputV1.

        :param installer: The installer of this PluginOutputV1.
        :type: IdentityPreviewV1
        """

        self._installer = installer

    @property
    def is_archived(self):
        """
        Gets the is_archived of this PluginOutputV1.
        Whether item is archived

        :return: The is_archived of this PluginOutputV1.
        :rtype: bool
        """
        return self._is_archived

    @is_archived.setter
    def is_archived(self, is_archived):
        """
        Sets the is_archived of this PluginOutputV1.
        Whether item is archived

        :param is_archived: The is_archived of this PluginOutputV1.
        :type: bool
        """

        self._is_archived = is_archived

    @property
    def is_redacted(self):
        """
        Gets the is_redacted of this PluginOutputV1.
        Whether item is redacted

        :return: The is_redacted of this PluginOutputV1.
        :rtype: bool
        """
        return self._is_redacted

    @is_redacted.setter
    def is_redacted(self, is_redacted):
        """
        Sets the is_redacted of this PluginOutputV1.
        Whether item is redacted

        :param is_redacted: The is_redacted of this PluginOutputV1.
        :type: bool
        """

        self._is_redacted = is_redacted

    @property
    def name(self):
        """
        Gets the name of this PluginOutputV1.
        The human readable name

        :return: The name of this PluginOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this PluginOutputV1.
        The human readable name

        :param name: The name of this PluginOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def options(self):
        """
        Gets the options of this PluginOutputV1.
        Plugin-specific configuration settings

        :return: The options of this PluginOutputV1.
        :rtype: object
        """
        return self._options

    @options.setter
    def options(self, options):
        """
        Sets the options of this PluginOutputV1.
        Plugin-specific configuration settings

        :param options: The options of this PluginOutputV1.
        :type: object
        """

        self._options = options

    @property
    def status_message(self):
        """
        Gets the status_message of this PluginOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation

        :return: The status_message of this PluginOutputV1.
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message):
        """
        Sets the status_message of this PluginOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation

        :param status_message: The status_message of this PluginOutputV1.
        :type: str
        """

        self._status_message = status_message

    @property
    def translation_key(self):
        """
        Gets the translation_key of this PluginOutputV1.
        The item's translation key, if any

        :return: The translation_key of this PluginOutputV1.
        :rtype: str
        """
        return self._translation_key

    @translation_key.setter
    def translation_key(self, translation_key):
        """
        Sets the translation_key of this PluginOutputV1.
        The item's translation key, if any

        :param translation_key: The translation_key of this PluginOutputV1.
        :type: str
        """

        self._translation_key = translation_key

    @property
    def type(self):
        """
        Gets the type of this PluginOutputV1.
        The type of the item

        :return: The type of this PluginOutputV1.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this PluginOutputV1.
        The type of the item

        :param type: The type of this PluginOutputV1.
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")

        self._type = type

    @property
    def version(self):
        """
        Gets the version of this PluginOutputV1.
        The plugin version (e.g. \"1.0.0\")

        :return: The version of this PluginOutputV1.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this PluginOutputV1.
        The plugin version (e.g. \"1.0.0\")

        :param version: The version of this PluginOutputV1.
        :type: str
        """

        self._version = version

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PluginOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ModelTableApplicationOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'compute_output': 'TableComputeOutputV1',
        'feature_values': 'list[FeatureValueOutputV1]'
    }

    attribute_map = {
        'compute_output': 'computeOutput',
        'feature_values': 'featureValues'
    }

    def __init__(self, compute_output=None, feature_values=None):
        """
        ModelTableApplicationOutputV1 - a model defined in Swagger
        """

        self._compute_output = None
        self._feature_values = None

        if compute_output is not None:
          self.compute_output = compute_output
        if feature_values is not None:
          self.feature_values = feature_values

    @property
    def compute_output(self):
        """
        Gets the compute_output of this ModelTableApplicationOutputV1.

        :return: The compute_output of this ModelTableApplicationOutputV1.
        :rtype: TableComputeOutputV1
        """
        return self._compute_output

    @compute_output.setter
    def compute_output(self, compute_output):
        """
        Sets the compute_output of this ModelTableApplicationOutputV1.

        :param compute_output: The compute_output of this ModelTableApplicationOutputV1.
        :type: TableComputeOutputV1
        """

        self._compute_output = compute_output

    @property
    def feature_values(self):
        """
        Gets the feature_values of this ModelTableApplicationOutputV1.
        List of feature values applied to the table

        :return: The feature_values of this ModelTableApplicationOutputV1.
        :rtype: list[FeatureValueOutputV1]
        """
        return self._feature_values

    @feature_values.setter
    def feature_values(self, feature_values):
        """
        Sets the feature_values of this ModelTableApplicationOutputV1.
        List of feature values applied to the table

        :param feature_values: The feature_values of this ModelTableApplicationOutputV1.
        :type: list[FeatureValueOutputV1]
        """

        self._feature_values = feature_values

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ModelTableApplicationOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class LabelHierarchyOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'category_id': 'str',
        'category_name': 'str',
        'children': 'list[LabelHierarchyOutputV1]',
        'label_id': 'str',
        'label_name': 'str'
    }

    attribute_map = {
        'category_id': 'categoryId',
        'category_name': 'categoryName',
        'children': 'children',
        'label_id': 'labelId',
        'label_name': 'labelName'
    }

    def __init__(self, category_id=None, category_name=None, children=None, label_id=None, label_name=None):
        """
        LabelHierarchyOutputV1 - a model defined in Swagger
        """

        self._category_id = None
        self._category_name = None
        self._children = None
        self._label_id = None
        self._label_name = None

        if category_id is not None:
          self.category_id = category_id
        if category_name is not None:
          self.category_name = category_name
        if children is not None:
          self.children = children
        if label_id is not None:
          self.label_id = label_id
        if label_name is not None:
          self.label_name = label_name

    @property
    def category_id(self):
        """
        Gets the category_id of this LabelHierarchyOutputV1.
        ID of the label category

        :return: The category_id of this LabelHierarchyOutputV1.
        :rtype: str
        """
        return self._category_id

    @category_id.setter
    def category_id(self, category_id):
        """
        Sets the category_id of this LabelHierarchyOutputV1.
        ID of the label category

        :param category_id: The category_id of this LabelHierarchyOutputV1.
        :type: str
        """
        if category_id is None:
            raise ValueError("Invalid value for `category_id`, must not be `None`")

        self._category_id = category_id

    @property
    def category_name(self):
        """
        Gets the category_name of this LabelHierarchyOutputV1.
        Name of the label category

        :return: The category_name of this LabelHierarchyOutputV1.
        :rtype: str
        """
        return self._category_name

    @category_name.setter
    def category_name(self, category_name):
        """
        Sets the category_name of this LabelHierarchyOutputV1.
        Name of the label category

        :param category_name: The category_name of this LabelHierarchyOutputV1.
        :type: str
        """
        if category_name is None:
            raise ValueError("Invalid value for `category_name`, must not be `None`")

        self._category_name = category_name

    @property
    def children(self):
        """
        Gets the children of this LabelHierarchyOutputV1.
        Children labels in the hierarchy

        :return: The children of this LabelHierarchyOutputV1.
        :rtype: list[LabelHierarchyOutputV1]
        """
        return self._children

    @children.setter
    def children(self, children):
        """
        Sets the children of this LabelHierarchyOutputV1.
        Children labels in the hierarchy

        :param children: The children of this LabelHierarchyOutputV1.
        :type: list[LabelHierarchyOutputV1]
        """
        if children is None:
            raise ValueError("Invalid value for `children`, must not be `None`")

        self._children = children

    @property
    def label_id(self):
        """
        Gets the label_id of this LabelHierarchyOutputV1.
        ID of the label

        :return: The label_id of this LabelHierarchyOutputV1.
        :rtype: str
        """
        return self._label_id

    @label_id.setter
    def label_id(self, label_id):
        """
        Sets the label_id of this LabelHierarchyOutputV1.
        ID of the label

        :param label_id: The label_id of this LabelHierarchyOutputV1.
        :type: str
        """
        if label_id is None:
            raise ValueError("Invalid value for `label_id`, must not be `None`")

        self._label_id = label_id

    @property
    def label_name(self):
        """
        Gets the label_name of this LabelHierarchyOutputV1.
        Name of the label

        :return: The label_name of this LabelHierarchyOutputV1.
        :rtype: str
        """
        return self._label_name

    @label_name.setter
    def label_name(self, label_name):
        """
        Sets the label_name of this LabelHierarchyOutputV1.
        Name of the label

        :param label_name: The label_name of this LabelHierarchyOutputV1.
        :type: str
        """
        if label_name is None:
            raise ValueError("Invalid value for `label_name`, must not be `None`")

        self._label_name = label_name

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, LabelHierarchyOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ColumnRuleConcatInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_indexes': 'list[int]',
        'prefix': 'str',
        'separator': 'str',
        'suffix': 'str'
    }

    attribute_map = {
        'column_indexes': 'columnIndexes',
        'prefix': 'prefix',
        'separator': 'separator',
        'suffix': 'suffix'
    }

    def __init__(self, column_indexes=None, prefix=None, separator=None, suffix=None):
        """
        ColumnRuleConcatInputV1 - a model defined in Swagger
        """

        self._column_indexes = None
        self._prefix = None
        self._separator = None
        self._suffix = None

        if column_indexes is not None:
          self.column_indexes = column_indexes
        if prefix is not None:
          self.prefix = prefix
        if separator is not None:
          self.separator = separator
        if suffix is not None:
          self.suffix = suffix

    @property
    def column_indexes(self):
        """
        Gets the column_indexes of this ColumnRuleConcatInputV1.
        The indexes of the columns that references the items to concatenate. A column index is 1-based

        :return: The column_indexes of this ColumnRuleConcatInputV1.
        :rtype: list[int]
        """
        return self._column_indexes

    @column_indexes.setter
    def column_indexes(self, column_indexes):
        """
        Sets the column_indexes of this ColumnRuleConcatInputV1.
        The indexes of the columns that references the items to concatenate. A column index is 1-based

        :param column_indexes: The column_indexes of this ColumnRuleConcatInputV1.
        :type: list[int]
        """
        if column_indexes is None:
            raise ValueError("Invalid value for `column_indexes`, must not be `None`")

        self._column_indexes = column_indexes

    @property
    def prefix(self):
        """
        Gets the prefix of this ColumnRuleConcatInputV1.
        The prefix before the concatenated columns. Defaults to ''

        :return: The prefix of this ColumnRuleConcatInputV1.
        :rtype: str
        """
        return self._prefix

    @prefix.setter
    def prefix(self, prefix):
        """
        Sets the prefix of this ColumnRuleConcatInputV1.
        The prefix before the concatenated columns. Defaults to ''

        :param prefix: The prefix of this ColumnRuleConcatInputV1.
        :type: str
        """

        self._prefix = prefix

    @property
    def separator(self):
        """
        Gets the separator of this ColumnRuleConcatInputV1.
        The separator between columns being concatenated. Defaults to ''

        :return: The separator of this ColumnRuleConcatInputV1.
        :rtype: str
        """
        return self._separator

    @separator.setter
    def separator(self, separator):
        """
        Sets the separator of this ColumnRuleConcatInputV1.
        The separator between columns being concatenated. Defaults to ''

        :param separator: The separator of this ColumnRuleConcatInputV1.
        :type: str
        """

        self._separator = separator

    @property
    def suffix(self):
        """
        Gets the suffix of this ColumnRuleConcatInputV1.
        The suffix after the concatenated columns. Defaults to ''

        :return: The suffix of this ColumnRuleConcatInputV1.
        :rtype: str
        """
        return self._suffix

    @suffix.setter
    def suffix(self, suffix):
        """
        Sets the suffix of this ColumnRuleConcatInputV1.
        The suffix after the concatenated columns. Defaults to ''

        :param suffix: The suffix of this ColumnRuleConcatInputV1.
        :type: str
        """

        self._suffix = suffix

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ColumnRuleConcatInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class HierarchyInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'alias_column_id': 'str',
        'description': 'str',
        'filter_grouping': 'str',
        'name': 'str',
        'scoped_to': 'str',
        'table_definition_id': 'str',
        'view_columns': 'list[ViewColumnInputV1]'
    }

    attribute_map = {
        'alias_column_id': 'aliasColumnId',
        'description': 'description',
        'filter_grouping': 'filterGrouping',
        'name': 'name',
        'scoped_to': 'scopedTo',
        'table_definition_id': 'tableDefinitionId',
        'view_columns': 'viewColumns'
    }

    def __init__(self, alias_column_id=None, description=None, filter_grouping=None, name=None, scoped_to=None, table_definition_id=None, view_columns=None):
        """
        HierarchyInputV1 - a model defined in Swagger
        """

        self._alias_column_id = None
        self._description = None
        self._filter_grouping = None
        self._name = None
        self._scoped_to = None
        self._table_definition_id = None
        self._view_columns = None

        if alias_column_id is not None:
          self.alias_column_id = alias_column_id
        if description is not None:
          self.description = description
        if filter_grouping is not None:
          self.filter_grouping = filter_grouping
        if name is not None:
          self.name = name
        if scoped_to is not None:
          self.scoped_to = scoped_to
        if table_definition_id is not None:
          self.table_definition_id = table_definition_id
        if view_columns is not None:
          self.view_columns = view_columns

    @property
    def alias_column_id(self):
        """
        Gets the alias_column_id of this HierarchyInputV1.
        The ID of the column the Hierarchy should use for aliases. If not provided item names will be used for the items in the hierarchy.

        :return: The alias_column_id of this HierarchyInputV1.
        :rtype: str
        """
        return self._alias_column_id

    @alias_column_id.setter
    def alias_column_id(self, alias_column_id):
        """
        Sets the alias_column_id of this HierarchyInputV1.
        The ID of the column the Hierarchy should use for aliases. If not provided item names will be used for the items in the hierarchy.

        :param alias_column_id: The alias_column_id of this HierarchyInputV1.
        :type: str
        """

        self._alias_column_id = alias_column_id

    @property
    def description(self):
        """
        Gets the description of this HierarchyInputV1.
        Clarifying information or other plain language description of this item. An input of just whitespaces is equivalent to a null input.

        :return: The description of this HierarchyInputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this HierarchyInputV1.
        Clarifying information or other plain language description of this item. An input of just whitespaces is equivalent to a null input.

        :param description: The description of this HierarchyInputV1.
        :type: str
        """

        self._description = description

    @property
    def filter_grouping(self):
        """
        Gets the filter_grouping of this HierarchyInputV1.
        The logical filter grouping for column filters, if not provided all filters will be applied with the AND operator. All view column filters must have a numeric filter group label that is used in the filter grouping expression. The filter grouping expression is a logical expression that includes filters by filter group label separated by AND or OR operators with optional parentheses for ordering. <br><b>Example:</b> 1 AND (2 OR 3) <br><b>Example:</b> ((1 OR 4) AND (2 OR 3)) OR 5

        :return: The filter_grouping of this HierarchyInputV1.
        :rtype: str
        """
        return self._filter_grouping

    @filter_grouping.setter
    def filter_grouping(self, filter_grouping):
        """
        Sets the filter_grouping of this HierarchyInputV1.
        The logical filter grouping for column filters, if not provided all filters will be applied with the AND operator. All view column filters must have a numeric filter group label that is used in the filter grouping expression. The filter grouping expression is a logical expression that includes filters by filter group label separated by AND or OR operators with optional parentheses for ordering. <br><b>Example:</b> 1 AND (2 OR 3) <br><b>Example:</b> ((1 OR 4) AND (2 OR 3)) OR 5

        :param filter_grouping: The filter_grouping of this HierarchyInputV1.
        :type: str
        """

        self._filter_grouping = filter_grouping

    @property
    def name(self):
        """
        Gets the name of this HierarchyInputV1.
        Human readable name. Required during creation. An input of just whitespaces is equivalent to a null input.

        :return: The name of this HierarchyInputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this HierarchyInputV1.
        Human readable name. Required during creation. An input of just whitespaces is equivalent to a null input.

        :param name: The name of this HierarchyInputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this HierarchyInputV1.
        The ID of the workbook to which the hierarchy will be scoped. If not provided, the hierarchy will be globally scoped.

        :return: The scoped_to of this HierarchyInputV1.
        :rtype: str
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this HierarchyInputV1.
        The ID of the workbook to which the hierarchy will be scoped. If not provided, the hierarchy will be globally scoped.

        :param scoped_to: The scoped_to of this HierarchyInputV1.
        :type: str
        """

        self._scoped_to = scoped_to

    @property
    def table_definition_id(self):
        """
        Gets the table_definition_id of this HierarchyInputV1.
        The ID of the Item Table that the Hierarchy is created from

        :return: The table_definition_id of this HierarchyInputV1.
        :rtype: str
        """
        return self._table_definition_id

    @table_definition_id.setter
    def table_definition_id(self, table_definition_id):
        """
        Sets the table_definition_id of this HierarchyInputV1.
        The ID of the Item Table that the Hierarchy is created from

        :param table_definition_id: The table_definition_id of this HierarchyInputV1.
        :type: str
        """

        self._table_definition_id = table_definition_id

    @property
    def view_columns(self):
        """
        Gets the view_columns of this HierarchyInputV1.
        View Columns for the Table that correspond to Column Definitions. They contain grouping, filtering and sorting information for a given Hierarchy view applied to an Item Table.

        :return: The view_columns of this HierarchyInputV1.
        :rtype: list[ViewColumnInputV1]
        """
        return self._view_columns

    @view_columns.setter
    def view_columns(self, view_columns):
        """
        Sets the view_columns of this HierarchyInputV1.
        View Columns for the Table that correspond to Column Definitions. They contain grouping, filtering and sorting information for a given Hierarchy view applied to an Item Table.

        :param view_columns: The view_columns of this HierarchyInputV1.
        :type: list[ViewColumnInputV1]
        """
        if view_columns is None:
            raise ValueError("Invalid value for `view_columns`, must not be `None`")

        self._view_columns = view_columns

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, HierarchyInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class CommentCategoryInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'help_text': 'str',
        'icon': 'str',
        'name': 'str',
        'title': 'str'
    }

    attribute_map = {
        'help_text': 'helpText',
        'icon': 'icon',
        'name': 'name',
        'title': 'title'
    }

    def __init__(self, help_text=None, icon=None, name=None, title=None):
        """
        CommentCategoryInputV1 - a model defined in Swagger
        """

        self._help_text = None
        self._icon = None
        self._name = None
        self._title = None

        if help_text is not None:
          self.help_text = help_text
        if icon is not None:
          self.icon = icon
        if name is not None:
          self.name = name
        if title is not None:
          self.title = title

    @property
    def help_text(self):
        """
        Gets the help_text of this CommentCategoryInputV1.
        Help text for the comment category (displayed as placeholder)

        :return: The help_text of this CommentCategoryInputV1.
        :rtype: str
        """
        return self._help_text

    @help_text.setter
    def help_text(self, help_text):
        """
        Sets the help_text of this CommentCategoryInputV1.
        Help text for the comment category (displayed as placeholder)

        :param help_text: The help_text of this CommentCategoryInputV1.
        :type: str
        """

        self._help_text = help_text

    @property
    def icon(self):
        """
        Gets the icon of this CommentCategoryInputV1.
        Icon of the comment category

        :return: The icon of this CommentCategoryInputV1.
        :rtype: str
        """
        return self._icon

    @icon.setter
    def icon(self, icon):
        """
        Sets the icon of this CommentCategoryInputV1.
        Icon of the comment category

        :param icon: The icon of this CommentCategoryInputV1.
        :type: str
        """

        self._icon = icon

    @property
    def name(self):
        """
        Gets the name of this CommentCategoryInputV1.
        Name of the comment category

        :return: The name of this CommentCategoryInputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CommentCategoryInputV1.
        Name of the comment category

        :param name: The name of this CommentCategoryInputV1.
        :type: str
        """

        self._name = name

    @property
    def title(self):
        """
        Gets the title of this CommentCategoryInputV1.
        Title of the comment category (displayed as column header)

        :return: The title of this CommentCategoryInputV1.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this CommentCategoryInputV1.
        Title of the comment category (displayed as column header)

        :param title: The title of this CommentCategoryInputV1.
        :type: str
        """

        self._title = title

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CommentCategoryInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class TableResultOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cursor_key': 'str',
        'has_more': 'bool',
        'headers': 'list[ColumnHeaderOutputV1]',
        'rows': 'list[list[object]]'
    }

    attribute_map = {
        'cursor_key': 'cursorKey',
        'has_more': 'hasMore',
        'headers': 'headers',
        'rows': 'rows'
    }

    def __init__(self, cursor_key=None, has_more=None, headers=None, rows=None):
        """
        TableResultOutputV1 - a model defined in Swagger
        """

        self._cursor_key = None
        self._has_more = None
        self._headers = None
        self._rows = None

        if cursor_key is not None:
          self.cursor_key = cursor_key
        if has_more is not None:
          self.has_more = has_more
        if headers is not None:
          self.headers = headers
        if rows is not None:
          self.rows = rows

    @property
    def cursor_key(self):
        """
        Gets the cursor_key of this TableResultOutputV1.
        The cursor key to use for pagination. If null, there are no more rows

        :return: The cursor_key of this TableResultOutputV1.
        :rtype: str
        """
        return self._cursor_key

    @cursor_key.setter
    def cursor_key(self, cursor_key):
        """
        Sets the cursor_key of this TableResultOutputV1.
        The cursor key to use for pagination. If null, there are no more rows

        :param cursor_key: The cursor_key of this TableResultOutputV1.
        :type: str
        """

        self._cursor_key = cursor_key

    @property
    def has_more(self):
        """
        Gets the has_more of this TableResultOutputV1.
        Whether or not there are more rows in the data set

        :return: The has_more of this TableResultOutputV1.
        :rtype: bool
        """
        return self._has_more

    @has_more.setter
    def has_more(self, has_more):
        """
        Sets the has_more of this TableResultOutputV1.
        Whether or not there are more rows in the data set

        :param has_more: The has_more of this TableResultOutputV1.
        :type: bool
        """
        if has_more is None:
            raise ValueError("Invalid value for `has_more`, must not be `None`")

        self._has_more = has_more

    @property
    def headers(self):
        """
        Gets the headers of this TableResultOutputV1.
        The headers for the returned rows. The order of the headers will match the order of the datums in the rows

        :return: The headers of this TableResultOutputV1.
        :rtype: list[ColumnHeaderOutputV1]
        """
        return self._headers

    @headers.setter
    def headers(self, headers):
        """
        Sets the headers of this TableResultOutputV1.
        The headers for the returned rows. The order of the headers will match the order of the datums in the rows

        :param headers: The headers of this TableResultOutputV1.
        :type: list[ColumnHeaderOutputV1]
        """
        if headers is None:
            raise ValueError("Invalid value for `headers`, must not be `None`")

        self._headers = headers

    @property
    def rows(self):
        """
        Gets the rows of this TableResultOutputV1.
        The list of all rows belonging to this table. Each row is a list where its index will correspond to the same index in the headers

        :return: The rows of this TableResultOutputV1.
        :rtype: list[list[object]]
        """
        return self._rows

    @rows.setter
    def rows(self, rows):
        """
        Sets the rows of this TableResultOutputV1.
        The list of all rows belonging to this table. Each row is a list where its index will correspond to the same index in the headers

        :param rows: The rows of this TableResultOutputV1.
        :type: list[list[object]]
        """
        if rows is None:
            raise ValueError("Invalid value for `rows`, must not be `None`")

        self._rows = rows

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TableResultOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class CapsuleEventInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'condition_id': 'str',
        'end': 'object',
        'id': 'str',
        'properties': 'list[TablePropertyInputV1]',
        'start': 'object'
    }

    attribute_map = {
        'condition_id': 'conditionId',
        'end': 'end',
        'id': 'id',
        'properties': 'properties',
        'start': 'start'
    }

    def __init__(self, condition_id=None, end=None, id=None, properties=None, start=None):
        """
        CapsuleEventInputV1 - a model defined in Swagger
        """

        self._condition_id = None
        self._end = None
        self._id = None
        self._properties = None
        self._start = None

        if condition_id is not None:
          self.condition_id = condition_id
        if end is not None:
          self.end = end
        if id is not None:
          self.id = id
        if properties is not None:
          self.properties = properties
        if start is not None:
          self.start = start

    @property
    def condition_id(self):
        """
        Gets the condition_id of this CapsuleEventInputV1.
        The ID of the condition that this capsule belongs to

        :return: The condition_id of this CapsuleEventInputV1.
        :rtype: str
        """
        return self._condition_id

    @condition_id.setter
    def condition_id(self, condition_id):
        """
        Sets the condition_id of this CapsuleEventInputV1.
        The ID of the condition that this capsule belongs to

        :param condition_id: The condition_id of this CapsuleEventInputV1.
        :type: str
        """
        if condition_id is None:
            raise ValueError("Invalid value for `condition_id`, must not be `None`")

        self._condition_id = condition_id

    @property
    def end(self):
        """
        Gets the end of this CapsuleEventInputV1.
        The end of the capsule, either in nanoseconds or an ISO-8601 timestamp

        :return: The end of this CapsuleEventInputV1.
        :rtype: object
        """
        return self._end

    @end.setter
    def end(self, end):
        """
        Sets the end of this CapsuleEventInputV1.
        The end of the capsule, either in nanoseconds or an ISO-8601 timestamp

        :param end: The end of this CapsuleEventInputV1.
        :type: object
        """
        if end is None:
            raise ValueError("Invalid value for `end`, must not be `None`")

        self._end = end

    @property
    def id(self):
        """
        Gets the id of this CapsuleEventInputV1.
        The unique ID of the capsule

        :return: The id of this CapsuleEventInputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CapsuleEventInputV1.
        The unique ID of the capsule

        :param id: The id of this CapsuleEventInputV1.
        :type: str
        """

        self._id = id

    @property
    def properties(self):
        """
        Gets the properties of this CapsuleEventInputV1.
        A list of properties representing the capsule properties

        :return: The properties of this CapsuleEventInputV1.
        :rtype: list[TablePropertyInputV1]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this CapsuleEventInputV1.
        A list of properties representing the capsule properties

        :param properties: The properties of this CapsuleEventInputV1.
        :type: list[TablePropertyInputV1]
        """

        self._properties = properties

    @property
    def start(self):
        """
        Gets the start of this CapsuleEventInputV1.
        The start of the capsule, either in nanoseconds or an ISO-8601 timestamp

        :return: The start of this CapsuleEventInputV1.
        :rtype: object
        """
        return self._start

    @start.setter
    def start(self, start):
        """
        Sets the start of this CapsuleEventInputV1.
        The start of the capsule, either in nanoseconds or an ISO-8601 timestamp

        :param start: The start of this CapsuleEventInputV1.
        :type: object
        """
        if start is None:
            raise ValueError("Invalid value for `start`, must not be `None`")

        self._start = start

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CapsuleEventInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class TableDataQueryInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'columns_to_include': 'list[str]',
        'condition_monitor_id': 'str',
        'cursor': 'Cursor',
        'filter': 'Filter',
        'group_by': 'GroupBy',
        'include_overrides': 'bool',
        'limit': 'int',
        'properties_to_include': 'list[PropertiesForItemUUIDColumn]',
        'sorts': 'list[Sort]',
        'table_formulas': 'list[TableFormula]',
        'tables_to_join': 'list[TableJoinInput]',
        'use_distinct': 'bool',
        'virtual_columns': 'VirtualColumns'
    }

    attribute_map = {
        'columns_to_include': 'columnsToInclude',
        'condition_monitor_id': 'conditionMonitorId',
        'cursor': 'cursor',
        'filter': 'filter',
        'group_by': 'groupBy',
        'include_overrides': 'includeOverrides',
        'limit': 'limit',
        'properties_to_include': 'propertiesToInclude',
        'sorts': 'sorts',
        'table_formulas': 'tableFormulas',
        'tables_to_join': 'tablesToJoin',
        'use_distinct': 'useDistinct',
        'virtual_columns': 'virtualColumns'
    }

    def __init__(self, columns_to_include=None, condition_monitor_id=None, cursor=None, filter=None, group_by=None, include_overrides=None, limit=None, properties_to_include=None, sorts=None, table_formulas=None, tables_to_join=None, use_distinct=None, virtual_columns=None):
        """
        TableDataQueryInputV1 - a model defined in Swagger
        """

        self._columns_to_include = None
        self._condition_monitor_id = None
        self._cursor = None
        self._filter = None
        self._group_by = None
        self._include_overrides = None
        self._limit = None
        self._properties_to_include = None
        self._sorts = None
        self._table_formulas = None
        self._tables_to_join = None
        self._use_distinct = None
        self._virtual_columns = None

        if columns_to_include is not None:
          self.columns_to_include = columns_to_include
        if condition_monitor_id is not None:
          self.condition_monitor_id = condition_monitor_id
        if cursor is not None:
          self.cursor = cursor
        if filter is not None:
          self.filter = filter
        if group_by is not None:
          self.group_by = group_by
        if include_overrides is not None:
          self.include_overrides = include_overrides
        if limit is not None:
          self.limit = limit
        if properties_to_include is not None:
          self.properties_to_include = properties_to_include
        if sorts is not None:
          self.sorts = sorts
        if table_formulas is not None:
          self.table_formulas = table_formulas
        if tables_to_join is not None:
          self.tables_to_join = tables_to_join
        if use_distinct is not None:
          self.use_distinct = use_distinct
        if virtual_columns is not None:
          self.virtual_columns = virtual_columns

    @property
    def columns_to_include(self):
        """
        Gets the columns_to_include of this TableDataQueryInputV1.
        What columns to include in the result. If set to null or not provided, all columns are returned. To include context columns, prepend the column with either 'context_comments.', 'context_label.', or 'context_opaque.'

        :return: The columns_to_include of this TableDataQueryInputV1.
        :rtype: list[str]
        """
        return self._columns_to_include

    @columns_to_include.setter
    def columns_to_include(self, columns_to_include):
        """
        Sets the columns_to_include of this TableDataQueryInputV1.
        What columns to include in the result. If set to null or not provided, all columns are returned. To include context columns, prepend the column with either 'context_comments.', 'context_label.', or 'context_opaque.'

        :param columns_to_include: The columns_to_include of this TableDataQueryInputV1.
        :type: list[str]
        """

        self._columns_to_include = columns_to_include

    @property
    def condition_monitor_id(self):
        """
        Gets the condition_monitor_id of this TableDataQueryInputV1.
        The condition monitor ID to use in condition monitor related queries

        :return: The condition_monitor_id of this TableDataQueryInputV1.
        :rtype: str
        """
        return self._condition_monitor_id

    @condition_monitor_id.setter
    def condition_monitor_id(self, condition_monitor_id):
        """
        Sets the condition_monitor_id of this TableDataQueryInputV1.
        The condition monitor ID to use in condition monitor related queries

        :param condition_monitor_id: The condition_monitor_id of this TableDataQueryInputV1.
        :type: str
        """

        self._condition_monitor_id = condition_monitor_id

    @property
    def cursor(self):
        """
        Gets the cursor of this TableDataQueryInputV1.

        :return: The cursor of this TableDataQueryInputV1.
        :rtype: Cursor
        """
        return self._cursor

    @cursor.setter
    def cursor(self, cursor):
        """
        Sets the cursor of this TableDataQueryInputV1.

        :param cursor: The cursor of this TableDataQueryInputV1.
        :type: Cursor
        """

        self._cursor = cursor

    @property
    def filter(self):
        """
        Gets the filter of this TableDataQueryInputV1.

        :return: The filter of this TableDataQueryInputV1.
        :rtype: Filter
        """
        return self._filter

    @filter.setter
    def filter(self, filter):
        """
        Sets the filter of this TableDataQueryInputV1.

        :param filter: The filter of this TableDataQueryInputV1.
        :type: Filter
        """

        self._filter = filter

    @property
    def group_by(self):
        """
        Gets the group_by of this TableDataQueryInputV1.

        :return: The group_by of this TableDataQueryInputV1.
        :rtype: GroupBy
        """
        return self._group_by

    @group_by.setter
    def group_by(self, group_by):
        """
        Sets the group_by of this TableDataQueryInputV1.

        :param group_by: The group_by of this TableDataQueryInputV1.
        :type: GroupBy
        """

        self._group_by = group_by

    @property
    def include_overrides(self):
        """
        Gets the include_overrides of this TableDataQueryInputV1.
        Include override columns in the result.

        :return: The include_overrides of this TableDataQueryInputV1.
        :rtype: bool
        """
        return self._include_overrides

    @include_overrides.setter
    def include_overrides(self, include_overrides):
        """
        Sets the include_overrides of this TableDataQueryInputV1.
        Include override columns in the result.

        :param include_overrides: The include_overrides of this TableDataQueryInputV1.
        :type: bool
        """

        self._include_overrides = include_overrides

    @property
    def limit(self):
        """
        Gets the limit of this TableDataQueryInputV1.
        Maximum number of rows to return

        :return: The limit of this TableDataQueryInputV1.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """
        Sets the limit of this TableDataQueryInputV1.
        Maximum number of rows to return

        :param limit: The limit of this TableDataQueryInputV1.
        :type: int
        """
        if limit is None:
            raise ValueError("Invalid value for `limit`, must not be `None`")

        self._limit = limit

    @property
    def properties_to_include(self):
        """
        Gets the properties_to_include of this TableDataQueryInputV1.
        Any additional item properties to retrieve for an item. Only works for UUID columns.

        :return: The properties_to_include of this TableDataQueryInputV1.
        :rtype: list[PropertiesForItemUUIDColumn]
        """
        return self._properties_to_include

    @properties_to_include.setter
    def properties_to_include(self, properties_to_include):
        """
        Sets the properties_to_include of this TableDataQueryInputV1.
        Any additional item properties to retrieve for an item. Only works for UUID columns.

        :param properties_to_include: The properties_to_include of this TableDataQueryInputV1.
        :type: list[PropertiesForItemUUIDColumn]
        """

        self._properties_to_include = properties_to_include

    @property
    def sorts(self):
        """
        Gets the sorts of this TableDataQueryInputV1.
        The sort(s) to apply to the results

        :return: The sorts of this TableDataQueryInputV1.
        :rtype: list[Sort]
        """
        return self._sorts

    @sorts.setter
    def sorts(self, sorts):
        """
        Sets the sorts of this TableDataQueryInputV1.
        The sort(s) to apply to the results

        :param sorts: The sorts of this TableDataQueryInputV1.
        :type: list[Sort]
        """

        self._sorts = sorts

    @property
    def table_formulas(self):
        """
        Gets the table_formulas of this TableDataQueryInputV1.
        The formulas to run against the items in the table results. Each formula result will be returned as their own column in the order requested by the formula.  ColumnsToInclude must include the column containing the items to run the formula across.

        :return: The table_formulas of this TableDataQueryInputV1.
        :rtype: list[TableFormula]
        """
        return self._table_formulas

    @table_formulas.setter
    def table_formulas(self, table_formulas):
        """
        Sets the table_formulas of this TableDataQueryInputV1.
        The formulas to run against the items in the table results. Each formula result will be returned as their own column in the order requested by the formula.  ColumnsToInclude must include the column containing the items to run the formula across.

        :param table_formulas: The table_formulas of this TableDataQueryInputV1.
        :type: list[TableFormula]
        """

        self._table_formulas = table_formulas

    @property
    def tables_to_join(self):
        """
        Gets the tables_to_join of this TableDataQueryInputV1.
        Materialized tables to join and the columns to include from each table. If no columns are added, all will be fetched. Each UUID column in the table being fetched will be joined with the columnToJoin, or the item id column if blank

        :return: The tables_to_join of this TableDataQueryInputV1.
        :rtype: list[TableJoinInput]
        """
        return self._tables_to_join

    @tables_to_join.setter
    def tables_to_join(self, tables_to_join):
        """
        Sets the tables_to_join of this TableDataQueryInputV1.
        Materialized tables to join and the columns to include from each table. If no columns are added, all will be fetched. Each UUID column in the table being fetched will be joined with the columnToJoin, or the item id column if blank

        :param tables_to_join: The tables_to_join of this TableDataQueryInputV1.
        :type: list[TableJoinInput]
        """

        self._tables_to_join = tables_to_join

    @property
    def use_distinct(self):
        """
        Gets the use_distinct of this TableDataQueryInputV1.
        Include only distinct rows in the result. ColumnsToInclude must be included to use this and distinct will apply across all columns requested.

        :return: The use_distinct of this TableDataQueryInputV1.
        :rtype: bool
        """
        return self._use_distinct

    @use_distinct.setter
    def use_distinct(self, use_distinct):
        """
        Sets the use_distinct of this TableDataQueryInputV1.
        Include only distinct rows in the result. ColumnsToInclude must be included to use this and distinct will apply across all columns requested.

        :param use_distinct: The use_distinct of this TableDataQueryInputV1.
        :type: bool
        """

        self._use_distinct = use_distinct

    @property
    def virtual_columns(self):
        """
        Gets the virtual_columns of this TableDataQueryInputV1.

        :return: The virtual_columns of this TableDataQueryInputV1.
        :rtype: VirtualColumns
        """
        return self._virtual_columns

    @virtual_columns.setter
    def virtual_columns(self, virtual_columns):
        """
        Sets the virtual_columns of this TableDataQueryInputV1.

        :param virtual_columns: The virtual_columns of this TableDataQueryInputV1.
        :type: VirtualColumns
        """

        self._virtual_columns = virtual_columns

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TableDataQueryInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class MaterializedTableSourceV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'additional_column_properties': 'list[PropertiesForItemUUIDColumnInputV1]',
        'condition_and_metric_column': 'str',
        'condition_stats': 'list[ConditionTableStatInputForTableV1]',
        'table_id': 'str'
    }

    attribute_map = {
        'additional_column_properties': 'additionalColumnProperties',
        'condition_and_metric_column': 'conditionAndMetricColumn',
        'condition_stats': 'conditionStats',
        'table_id': 'tableId'
    }

    def __init__(self, additional_column_properties=None, condition_and_metric_column=None, condition_stats=None, table_id=None):
        """
        MaterializedTableSourceV1 - a model defined in Swagger
        """

        self._additional_column_properties = None
        self._condition_and_metric_column = None
        self._condition_stats = None
        self._table_id = None

        if additional_column_properties is not None:
          self.additional_column_properties = additional_column_properties
        if condition_and_metric_column is not None:
          self.condition_and_metric_column = condition_and_metric_column
        if condition_stats is not None:
          self.condition_stats = condition_stats
        if table_id is not None:
          self.table_id = table_id

    @property
    def additional_column_properties(self):
        """
        Gets the additional_column_properties of this MaterializedTableSourceV1.
        Additional column properties to fetch per row that will be concatenated onto each resulting capsule row

        :return: The additional_column_properties of this MaterializedTableSourceV1.
        :rtype: list[PropertiesForItemUUIDColumnInputV1]
        """
        return self._additional_column_properties

    @additional_column_properties.setter
    def additional_column_properties(self, additional_column_properties):
        """
        Sets the additional_column_properties of this MaterializedTableSourceV1.
        Additional column properties to fetch per row that will be concatenated onto each resulting capsule row

        :param additional_column_properties: The additional_column_properties of this MaterializedTableSourceV1.
        :type: list[PropertiesForItemUUIDColumnInputV1]
        """

        self._additional_column_properties = additional_column_properties

    @property
    def condition_and_metric_column(self):
        """
        Gets the condition_and_metric_column of this MaterializedTableSourceV1.
        The condition/condition metric column to run the table across

        :return: The condition_and_metric_column of this MaterializedTableSourceV1.
        :rtype: str
        """
        return self._condition_and_metric_column

    @condition_and_metric_column.setter
    def condition_and_metric_column(self, condition_and_metric_column):
        """
        Sets the condition_and_metric_column of this MaterializedTableSourceV1.
        The condition/condition metric column to run the table across

        :param condition_and_metric_column: The condition_and_metric_column of this MaterializedTableSourceV1.
        :type: str
        """
        if condition_and_metric_column is None:
            raise ValueError("Invalid value for `condition_and_metric_column`, must not be `None`")

        self._condition_and_metric_column = condition_and_metric_column

    @property
    def condition_stats(self):
        """
        Gets the condition_stats of this MaterializedTableSourceV1.
        The list of statistics to calculate for the condition columns

        :return: The condition_stats of this MaterializedTableSourceV1.
        :rtype: list[ConditionTableStatInputForTableV1]
        """
        return self._condition_stats

    @condition_stats.setter
    def condition_stats(self, condition_stats):
        """
        Sets the condition_stats of this MaterializedTableSourceV1.
        The list of statistics to calculate for the condition columns

        :param condition_stats: The condition_stats of this MaterializedTableSourceV1.
        :type: list[ConditionTableStatInputForTableV1]
        """

        self._condition_stats = condition_stats

    @property
    def table_id(self):
        """
        Gets the table_id of this MaterializedTableSourceV1.
        ID of the table to generate the condition table from

        :return: The table_id of this MaterializedTableSourceV1.
        :rtype: str
        """
        return self._table_id

    @table_id.setter
    def table_id(self, table_id):
        """
        Sets the table_id of this MaterializedTableSourceV1.
        ID of the table to generate the condition table from

        :param table_id: The table_id of this MaterializedTableSourceV1.
        :type: str
        """
        if table_id is None:
            raise ValueError("Invalid value for `table_id`, must not be `None`")

        self._table_id = table_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, MaterializedTableSourceV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

__version__ = "66.106.1"

# import models into sdk package
from .access_key_input_v1 import AccessKeyInputV1
from .access_key_output_list_v1 import AccessKeyOutputListV1
from .access_key_output_v1 import AccessKeyOutputV1
from .ace_input_v1 import AceInputV1
from .ace_output_v1 import AceOutputV1
from .acl_input_v1 import AclInputV1
from .acl_output_v1 import AclOutputV1
from .activity_graph_output_v1 import ActivityGraphOutputV1
from .activity_output_v1 import ActivityOutputV1
from .add_on_input_v1 import AddOnInputV1
from .add_on_output_list_v1 import AddOnOutputListV1
from .add_on_output_v1 import AddOnOutputV1
from .add_on_preview_output_list_v1 import AddOnPreviewOutputListV1
from .add_on_preview_v1 import AddOnPreviewV1
from .add_on_tool_input_v1 import AddOnToolInputV1
from .add_on_tool_output_v1 import AddOnToolOutputV1
from .administrator_contact_information_v1 import AdministratorContactInformationV1
from .agent_input_v1 import AgentInputV1
from .agent_key_output_v1 import AgentKeyOutputV1
from .agent_orchestrator_output_v1 import AgentOrchestratorOutputV1
from .agent_output_v1 import AgentOutputV1
from .agent_status_output_v1 import AgentStatusOutputV1
from .agent_status_v1 import AgentStatusV1
from .all_context_output_v1 import AllContextOutputV1
from .ancestor_filter_input_v1 import AncestorFilterInputV1
from .annotation_image_link_output_v1 import AnnotationImageLinkOutputV1
from .annotation_input_v1 import AnnotationInputV1
from .annotation_interest_input_v1 import AnnotationInterestInputV1
from .annotation_interest_output_v1 import AnnotationInterestOutputV1
from .annotation_list_output_v1 import AnnotationListOutputV1
from .annotation_output_v1 import AnnotationOutputV1
from .application_input_v1 import ApplicationInputV1
from .application_key_input_v1 import ApplicationKeyInputV1
from .application_output_v1 import ApplicationOutputV1
from .archive_output_v1 import ArchiveOutputV1
from .asset_batch_input_v1 import AssetBatchInputV1
from .asset_error import AssetError
from .asset_group_asset_input_v1 import AssetGroupAssetInputV1
from .asset_group_input_v1 import AssetGroupInputV1
from .asset_group_output_v1 import AssetGroupOutputV1
from .asset_group_root_input_v1 import AssetGroupRootInputV1
from .asset_group_tree_output_v1 import AssetGroupTreeOutputV1
from .asset_input_v1 import AssetInputV1
from .asset_output_v1 import AssetOutputV1
from .asset_selection_input_v1 import AssetSelectionInputV1
from .asset_selection_output_v1 import AssetSelectionOutputV1
from .asset_tree_batch_input_v1 import AssetTreeBatchInputV1
from .asset_tree_output_v1 import AssetTreeOutputV1
from .asset_tree_single_input_v1 import AssetTreeSingleInputV1
from .attachment_input_v1 import AttachmentInputV1
from .audit_output_list_v1 import AuditOutputListV1
from .audit_output_v1 import AuditOutputV1
from .auth_input_v1 import AuthInputV1
from .auth_providers_output_v1 import AuthProvidersOutputV1
from .authoritative_region_output_v1 import AuthoritativeRegionOutputV1
from .base_manual_run_input_v1 import BaseManualRunInputV1
from .base_output import BaseOutput
from .board_create_input_v1 import BoardCreateInputV1
from .board_filter_create_input_v1 import BoardFilterCreateInputV1
from .board_filter_input_v1 import BoardFilterInputV1
from .board_filter_output_v1 import BoardFilterOutputV1
from .board_filter_update_input_v1 import BoardFilterUpdateInputV1
from .board_output_list_v1 import BoardOutputListV1
from .board_output_v1 import BoardOutputV1
from .board_tile_get_input_v1 import BoardTileGetInputV1
from .board_update_input_v1 import BoardUpdateInputV1
from .boolean_config_field_v1 import BooleanConfigFieldV1
from .cache_block import CacheBlock
from .cache_info_v1 import CacheInfoV1
from .calculated_item_output_v1 import CalculatedItemOutputV1
from .calculated_table_column_dependency_output_v1 import CalculatedTableColumnDependencyOutputV1
from .calculated_table_column_input_v1 import CalculatedTableColumnInputV1
from .calculated_table_column_metadata_output_v1 import CalculatedTableColumnMetadataOutputV1
from .calculated_table_data_query_input_v1 import CalculatedTableDataQueryInputV1
from .calculated_table_input_v1 import CalculatedTableInputV1
from .calculated_table_list_output_v1 import CalculatedTableListOutputV1
from .calculated_table_output_v1 import CalculatedTableOutputV1
from .capability_inheritance_output_v1 import CapabilityInheritanceOutputV1
from .capsule_event_input_v1 import CapsuleEventInputV1
from .capsule_input_v1 import CapsuleInputV1
from .capsule_property_input_v1 import CapsulePropertyInputV1
from .capsule_property_output_v1 import CapsulePropertyOutputV1
from .capsule_v1 import CapsuleV1
from .capsules_input_v1 import CapsulesInputV1
from .capsules_output_v1 import CapsulesOutputV1
from .capsules_overwrite_input_v1 import CapsulesOverwriteInputV1
from .category_label_pair_input_v1 import CategoryLabelPairInputV1
from .channel_output_v1 import ChannelOutputV1
from .chart_data_point_output_v1 import ChartDataPointOutputV1
from .chart_data_result_output_v1 import ChartDataResultOutputV1
from .column_data_update_input_list_v1 import ColumnDataUpdateInputListV1
from .column_data_update_input_v1 import ColumnDataUpdateInputV1
from .column_definition_bulk_edit_input_list_v1 import ColumnDefinitionBulkEditInputListV1
from .column_definition_bulk_edit_input_v1 import ColumnDefinitionBulkEditInputV1
from .column_definition_input_list_v1 import ColumnDefinitionInputListV1
from .column_definition_input_v1 import ColumnDefinitionInputV1
from .column_definition_order_input_v1 import ColumnDefinitionOrderInputV1
from .column_definition_output_v1 import ColumnDefinitionOutputV1
from .column_header_output_v1 import ColumnHeaderOutputV1
from .column_model_input_v1 import ColumnModelInputV1
from .column_model_output import ColumnModelOutput
from .column_override_input_list_v1 import ColumnOverrideInputListV1
from .column_override_input_v1 import ColumnOverrideInputV1
from .column_rule_ancestor_input_v1 import ColumnRuleAncestorInputV1
from .column_rule_asset_creator_input_v1 import ColumnRuleAssetCreatorInputV1
from .column_rule_concat_input_v1 import ColumnRuleConcatInputV1
from .column_rule_constant_input_v1 import ColumnRuleConstantInputV1
from .column_rule_context_condition_input_v1 import ColumnRuleContextConditionInputV1
from .column_rule_datasource_input_v1 import ColumnRuleDatasourceInputV1
from .column_rule_descendant_input_v1 import ColumnRuleDescendantInputV1
from .column_rule_descendant_search_input_v1 import ColumnRuleDescendantSearchInputV1
from .column_rule_event_asset_creator_input_v1 import ColumnRuleEventAssetCreatorInputV1
from .column_rule_event_property_input_v1 import ColumnRuleEventPropertyInputV1
from .column_rule_find_descendant_input_v1 import ColumnRuleFindDescendantInputV1
from .column_rule_find_property_input_v1 import ColumnRuleFindPropertyInputV1
from .column_rule_formula_creator_input_v1 import ColumnRuleFormulaCreatorInputV1
from .column_rule_get_item_property_input_v1 import ColumnRuleGetItemPropertyInputV1
from .column_rule_input_v1 import ColumnRuleInputV1
from .column_rule_item_search_input_v1 import ColumnRuleItemSearchInputV1
from .column_rule_item_type_input_v1 import ColumnRuleItemTypeInputV1
from .column_rule_manager_input_v1 import ColumnRuleManagerInputV1
from .column_rule_output_v1 import ColumnRuleOutputV1
from .column_rule_path_input_v1 import ColumnRulePathInputV1
from .column_rule_path_search_input_v1 import ColumnRulePathSearchInputV1
from .column_rule_preserve_existing_input_v1 import ColumnRulePreserveExistingInputV1
from .column_rule_scalar_creator_input_v1 import ColumnRuleScalarCreatorInputV1
from .column_rule_search_ancestor_input_v1 import ColumnRuleSearchAncestorInputV1
from .column_rule_set_item_property_input_v1 import ColumnRuleSetItemPropertyInputV1
from .column_rule_text_extractor_input_v1 import ColumnRuleTextExtractorInputV1
from .column_rule_text_replacement_input_v1 import ColumnRuleTextReplacementInputV1
from .column_rule_tree_path_creator_input_v1 import ColumnRuleTreePathCreatorInputV1
from .column_values_output_v1 import ColumnValuesOutputV1
from .comment_category_input_v1 import CommentCategoryInputV1
from .comment_category_output_list_v1 import CommentCategoryOutputListV1
from .comment_category_output_v1 import CommentCategoryOutputV1
from .complex_object_config_field_v1 import ComplexObjectConfigFieldV1
from .composite_filter import CompositeFilter
from .condition_batch_input_v1 import ConditionBatchInputV1
from .condition_input_v1 import ConditionInputV1
from .condition_monitor_input_v1 import ConditionMonitorInputV1
from .condition_monitor_metadata_output_list_v1 import ConditionMonitorMetadataOutputListV1
from .condition_monitor_metadata_output_v1 import ConditionMonitorMetadataOutputV1
from .condition_monitor_notification_configuration_input_v1 import ConditionMonitorNotificationConfigurationInputV1
from .condition_monitor_output_v1 import ConditionMonitorOutputV1
from .condition_monitor_workbook_output_v1 import ConditionMonitorWorkbookOutputV1
from .condition_output_v1 import ConditionOutputV1
from .condition_source_v1 import ConditionSourceV1
from .condition_table_input_v1 import ConditionTableInputV1
from .condition_table_stat_input_for_direct_items_v1 import ConditionTableStatInputForDirectItemsV1
from .condition_table_stat_input_for_table_v1 import ConditionTableStatInputForTableV1
from .condition_update_input_v1 import ConditionUpdateInputV1
from .config_field_v1 import ConfigFieldV1
from .configuration_input_v1 import ConfigurationInputV1
from .configuration_option_input_v1 import ConfigurationOptionInputV1
from .configuration_option_output_simple_v1 import ConfigurationOptionOutputSimpleV1
from .configuration_option_output_v1 import ConfigurationOptionOutputV1
from .configuration_output_v1 import ConfigurationOutputV1
from .configured_directives_output_v1 import ConfiguredDirectivesOutputV1
from .connection_input_v1 import ConnectionInputV1
from .connection_output_v1 import ConnectionOutputV1
from .connection_status_output_v1 import ConnectionStatusOutputV1
from .connection_status_v1 import ConnectionStatusV1
from .connections_output_v1 import ConnectionsOutputV1
from .connector_input_v1 import ConnectorInputV1
from .connector_output_v1 import ConnectorOutputV1
from .connectors_output_v1 import ConnectorsOutputV1
from .content_input_v1 import ContentInputV1
from .content_output_v1 import ContentOutputV1
from .content_with_metadata_list_output_v1 import ContentWithMetadataListOutputV1
from .content_with_metadata_output_v1 import ContentWithMetadataOutputV1
from .context_comment_input_v1 import ContextCommentInputV1
from .context_comment_list_output_v1 import ContextCommentListOutputV1
from .context_comment_output_v1 import ContextCommentOutputV1
from .context_condition_output_list_v1 import ContextConditionOutputListV1
from .context_condition_output_v1 import ContextConditionOutputV1
from .context_id_input_v1 import ContextIdInputV1
from .context_item import ContextItem
from .context_label_input_v1 import ContextLabelInputV1
from .context_label_list_output_v1 import ContextLabelListOutputV1
from .context_label_output_v1 import ContextLabelOutputV1
from .context_label_with_id_input_v1 import ContextLabelWithIdInputV1
from .context_numeric_input_v1 import ContextNumericInputV1
from .context_numeric_list_output_v1 import ContextNumericListOutputV1
from .context_numeric_output_v1 import ContextNumericOutputV1
from .context_opaque_input_v1 import ContextOpaqueInputV1
from .context_opaque_list_output_v1 import ContextOpaqueListOutputV1
from .context_opaque_output_v1 import ContextOpaqueOutputV1
from .context_user import ContextUser
from .csv_datafile_output_v1 import CsvDatafileOutputV1
from .cursor import Cursor
from .datafile_input_v1 import DatafileInputV1
from .datafile_output_v1 import DatafileOutputV1
from .datafiles_csv_body import DatafilesCsvBody
from .datasource_access_stats_v1 import DatasourceAccessStatsV1
from .datasource_cache_clear_output_v1 import DatasourceCacheClearOutputV1
from .datasource_clean_up_input_v1 import DatasourceCleanUpInputV1
from .datasource_clean_up_output_v1 import DatasourceCleanUpOutputV1
from .datasource_input_v1 import DatasourceInputV1
from .datasource_output_list_v1 import DatasourceOutputListV1
from .datasource_output_v1 import DatasourceOutputV1
from .datasource_pair_output_v1 import DatasourcePairOutputV1
from .datasource_pairs_output_v1 import DatasourcePairsOutputV1
from .datasource_preview_v1 import DatasourcePreviewV1
from .datasource_statistics_v1 import DatasourceStatisticsV1
from .datasource_status_output_v1 import DatasourceStatusOutputV1
from .datasource_status_v1 import DatasourceStatusV1
from .datasource_summary_status_output_v1 import DatasourceSummaryStatusOutputV1
from .datasources_status_output_v1 import DatasourcesStatusOutputV1
from .date_range_input_v1 import DateRangeInputV1
from .date_range_output_v1 import DateRangeOutputV1
from .debug_cache_block_output_v1 import DebugCacheBlockOutputV1
from .delete_column_error_output_v1 import DeleteColumnErrorOutputV1
from .delete_result_output_v1 import DeleteResultOutputV1
from .delete_rows_input_v1 import DeleteRowsInputV1
from .delete_rows_output_v1 import DeleteRowsOutputV1
from .derived_feature_v1 import DerivedFeatureV1
from .detailed_meter_output_v1 import DetailedMeterOutputV1
from .detailed_timer_output_v1 import DetailedTimerOutputV1
from .direct_item_ids_source_v1 import DirectItemIdsSourceV1
from .directive_input_v1 import DirectiveInputV1
from .display_input_v1 import DisplayInputV1
from .display_output_list_v1 import DisplayOutputListV1
from .display_output_v1 import DisplayOutputV1
from .display_template_input_v1 import DisplayTemplateInputV1
from .display_template_output_list_v1 import DisplayTemplateOutputListV1
from .display_template_output_v1 import DisplayTemplateOutputV1
from .document_backup_output_v1 import DocumentBackupOutputV1
from .double_config_field_v1 import DoubleConfigFieldV1
from .duration_config_field_v1 import DurationConfigFieldV1
from .email_notification_recipient_output_v1 import EmailNotificationRecipientOutputV1
from .emailer_configuration_output_v1 import EmailerConfigurationOutputV1
from .enum_config_field_v1 import EnumConfigFieldV1
from .export_item_v1 import ExportItemV1
from .export_items_output_v1 import ExportItemsOutputV1
from .export_items_v1 import ExportItemsV1
from .export_preview_list_v1 import ExportPreviewListV1
from .export_preview_v1 import ExportPreviewV1
from .feature_argument_output_v1 import FeatureArgumentOutputV1
from .feature_output_v1 import FeatureOutputV1
from .feature_rule_v1 import FeatureRuleV1
from .feature_value_output_v1 import FeatureValueOutputV1
from .filter import Filter
from .fixed_list_search_v1 import FixedListSearchV1
from .folded_stack_node_v1 import FoldedStackNodeV1
from .folder_input_v1 import FolderInputV1
from .folder_navigation_output_v1 import FolderNavigationOutputV1
from .folder_output_v1 import FolderOutputV1
from .folder_search_results_v1 import FolderSearchResultsV1
from .formula_compile_input_v1 import FormulaCompileInputV1
from .formula_compile_output_v1 import FormulaCompileOutputV1
from .formula_compiler_error_output_v1 import FormulaCompilerErrorOutputV1
from .formula_dependency_input_v1 import FormulaDependencyInputV1
from .formula_doc_example_input_v1 import FormulaDocExampleInputV1
from .formula_doc_example_list_input_v1 import FormulaDocExampleListInputV1
from .formula_doc_input_v1 import FormulaDocInputV1
from .formula_doc_keyword_list_input_v1 import FormulaDocKeywordListInputV1
from .formula_doc_output_v1 import FormulaDocOutputV1
from .formula_doc_summaries_output_v1 import FormulaDocSummariesOutputV1
from .formula_doc_summary_output_v1 import FormulaDocSummaryOutputV1
from .formula_error_output_v1 import FormulaErrorOutputV1
from .formula_example_output_v1 import FormulaExampleOutputV1
from .formula_generic_output_v1 import FormulaGenericOutputV1
from .formula_item_input_v1 import FormulaItemInputV1
from .formula_item_output_v1 import FormulaItemOutputV1
from .formula_log_entry import FormulaLogEntry
from .formula_log_entry_details import FormulaLogEntryDetails
from .formula_log_v1 import FormulaLogV1
from .formula_package_import_input_v1 import FormulaPackageImportInputV1
from .formula_package_import_output_v1 import FormulaPackageImportOutputV1
from .formula_package_input_v1 import FormulaPackageInputV1
from .formula_package_output_v1 import FormulaPackageOutputV1
from .formula_parameter_input_v1 import FormulaParameterInputV1
from .formula_parameter_output_v1 import FormulaParameterOutputV1
from .formula_run_input_v1 import FormulaRunInputV1
from .formula_run_output_v1 import FormulaRunOutputV1
from .formula_token import FormulaToken
from .formula_update_input_v1 import FormulaUpdateInputV1
from .formula_upgrade_change_v1 import FormulaUpgradeChangeV1
from .formula_upgrade_output_v1 import FormulaUpgradeOutputV1
from .function_input_v1 import FunctionInputV1
from .function_parameter_output_v1 import FunctionParameterOutputV1
from .function_variant_output_v1 import FunctionVariantOutputV1
from .gauge_datum_v1 import GaugeDatumV1
from .generate_chart_data_input_v1 import GenerateChartDataInputV1
from .generic_event_input_v1 import GenericEventInputV1
from .generic_table_output_v1 import GenericTableOutputV1
from .get_add_on_tools_output_v1 import GetAddOnToolsOutputV1
from .get_all_context_input_v1 import GetAllContextInputV1
from .get_applications_output_v1 import GetApplicationsOutputV1
from .get_channels_output_v1 import GetChannelsOutputV1
from .get_condition_monitor_items_output_v1 import GetConditionMonitorItemsOutputV1
from .get_content_items_output_v1 import GetContentItemsOutputV1
from .get_context_condition_input_v1 import GetContextConditionInputV1
from .get_context_input_v1 import GetContextInputV1
from .get_date_ranges_output_v1 import GetDateRangesOutputV1
from .get_jobs_output_v1 import GetJobsOutputV1
from .get_metrics_output_v1 import GetMetricsOutputV1
from .get_organizations_output_v1 import GetOrganizationsOutputV1
from .get_projects_output_v1 import GetProjectsOutputV1
from .get_request_output_v1 import GetRequestOutputV1
from .get_requests_output_v1 import GetRequestsOutputV1
from .get_sample_output_v1 import GetSampleOutputV1
from .get_samples_output_v1 import GetSamplesOutputV1
from .get_signal_monitor_items_output_v1 import GetSignalMonitorItemsOutputV1
from .get_signals_output_v1 import GetSignalsOutputV1
from .graph_ql_input_v1 import GraphQLInputV1
from .graph_ql_output_v1 import GraphQLOutputV1
from .group_by import GroupBy
from .group_value_column import GroupValueColumn
from .hierarchy_input_v1 import HierarchyInputV1
from .hierarchy_node_output_list_v1 import HierarchyNodeOutputListV1
from .hierarchy_node_output_v1 import HierarchyNodeOutputV1
from .hierarchy_node_with_path_output_v1 import HierarchyNodeWithPathOutputV1
from .hierarchy_output_list_v1 import HierarchyOutputListV1
from .hierarchy_output_v1 import HierarchyOutputV1
from .hierarchy_search_v1 import HierarchySearchV1
from .hierarchy_validation_output_v1 import HierarchyValidationOutputV1
from .id_images_body import IdImagesBody
from .identity_mapping_list_v1 import IdentityMappingListV1
from .identity_mapping_v1 import IdentityMappingV1
from .identity_preview_list_v1 import IdentityPreviewListV1
from .identity_preview_v1 import IdentityPreviewV1
from .import_table_csv_output_v1 import ImportTableCSVOutputV1
from .indexing_parameters_input_v1 import IndexingParametersInputV1
from .input_feature_v1 import InputFeatureV1
from .installer_output_v1 import InstallerOutputV1
from .instance_output_mapping_v1 import InstanceOutputMappingV1
from .instance_output_paginated_list_v1 import InstanceOutputPaginatedListV1
from .instance_output_v1 import InstanceOutputV1
from .instance_retired_output_v1 import InstanceRetiredOutputV1
from .interval_v1 import IntervalV1
from .invalid_swap_out_v1 import InvalidSwapOutV1
from .issue_summary_output_v1 import IssueSummaryOutputV1
from .item_batch_output_v1 import ItemBatchOutputV1
from .item_dependency_output_v1 import ItemDependencyOutputV1
from .item_event_input_v1 import ItemEventInputV1
from .item_finder_input_v1 import ItemFinderInputV1
from .item_finder_output_list_v1 import ItemFinderOutputListV1
from .item_finder_output_v1 import ItemFinderOutputV1
from .item_finder_searches_input_v1 import ItemFinderSearchesInputV1
from .item_finder_searches_output_v1 import ItemFinderSearchesOutputV1
from .item_id_list_input_v1 import ItemIdListInputV1
from .item_metadata import ItemMetadata
from .item_output_v1 import ItemOutputV1
from .item_parameter_of_output_v1 import ItemParameterOfOutputV1
from .item_preview_list_v1 import ItemPreviewListV1
from .item_preview_v1 import ItemPreviewV1
from .item_preview_with_assets_v1 import ItemPreviewWithAssetsV1
from .item_search_input_v1 import ItemSearchInputV1
from .item_search_preview_list_v1 import ItemSearchPreviewListV1
from .item_search_preview_paginated_list_v1 import ItemSearchPreviewPaginatedListV1
from .item_search_preview_v1 import ItemSearchPreviewV1
from .item_swap_result_output_v1 import ItemSwapResultOutputV1
from .item_update_output_v1 import ItemUpdateOutputV1
from .item_user_attributes_input_v1 import ItemUserAttributesInputV1
from .item_user_attributes_output_v1 import ItemUserAttributesOutputV1
from .item_with_swap_pairs_v1 import ItemWithSwapPairsV1
from .jira_attachment import JiraAttachment
from .jira_attachment_media_type import JiraAttachmentMediaType
from .job_accepted_output_v1 import JobAcceptedOutputV1
from .job_output_v1 import JobOutputV1
from .join_input_v1 import JoinInputV1
from .json_backup_output_v1 import JsonBackupOutputV1
from .kpi_data_output_v1 import KpiDataOutputV1
from .label_category_input_v1 import LabelCategoryInputV1
from .label_category_output_list_v1 import LabelCategoryOutputListV1
from .label_category_output_v1 import LabelCategoryOutputV1
from .label_hierarchy_input_v1 import LabelHierarchyInputV1
from .label_hierarchy_output_list_v1 import LabelHierarchyOutputListV1
from .label_hierarchy_output_v1 import LabelHierarchyOutputV1
from .label_input_v1 import LabelInputV1
from .label_output_list_v1 import LabelOutputListV1
from .label_output_v1 import LabelOutputV1
from .last_run_state_output_v1 import LastRunStateOutputV1
from .license_importer_output_v1 import LicenseImporterOutputV1
from .license_status_output_v1 import LicenseStatusOutputV1
from .licensed_feature_status_output_v1 import LicensedFeatureStatusOutputV1
from .list_config_field_v1 import ListConfigFieldV1
from .lock_error_output_v1 import LockErrorOutputV1
from .lock_error_path_output_v1 import LockErrorPathOutputV1
from .lock_errors_output_v1 import LockErrorsOutputV1
from .lock_item_output_v1 import LockItemOutputV1
from .locked_item_list_output_v1 import LockedItemListOutputV1
from .log_message import LogMessage
from .log_message_input_v1 import LogMessageInputV1
from .log_message_output_v1 import LogMessageOutputV1
from .long_config_field_v1 import LongConfigFieldV1
from .manual_run_input_v1 import ManualRunInputV1
from .map_marker_rehydration_instructions_input_v1 import MapMarkerRehydrationInstructionsInputV1
from .map_marker_rehydration_instructions_output_v1 import MapMarkerRehydrationInstructionsOutputV1
from .markdown_item_input_v1 import MarkdownItemInputV1
from .markdown_item_list_v1 import MarkdownItemListV1
from .markdown_item_output_v1 import MarkdownItemOutputV1
from .markdown_link_upload_output_v1 import MarkdownLinkUploadOutputV1
from .markdown_links_body import MarkdownLinksBody
from .materialized_table_header_v1 import MaterializedTableHeaderV1
from .materialized_table_source_v1 import MaterializedTableSourceV1
from .materialized_table_v1 import MaterializedTableV1
from .mention_input_v1 import MentionInputV1
from .meter_datum_v1 import MeterDatumV1
from .migrate_editor_input_v1 import MigrateEditorInputV1
from .model_application_error_output_v1 import ModelApplicationErrorOutputV1
from .model_application_mapping_v1 import ModelApplicationMappingV1
from .model_boolean_constant_rule_v1 import ModelBooleanConstantRuleV1
from .model_derived_column_names_input_v1 import ModelDerivedColumnNamesInputV1
from .model_formula_creator_rule_v1 import ModelFormulaCreatorRuleV1
from .model_from_ids_input_v1 import ModelFromIdsInputV1
from .model_initial_application_input_v1 import ModelInitialApplicationInputV1
from .model_output_list_v1 import ModelOutputListV1
from .model_output_v1 import ModelOutputV1
from .model_reapplication_input_v1 import ModelReapplicationInputV1
from .model_rule_input_v1_list_string import ModelRuleInputV1ListString
from .model_rule_input_v1_object import ModelRuleInputV1Object
from .model_rule_input_v1_string import ModelRuleInputV1String
from .model_rule_input_v1_uuid import ModelRuleInputV1UUID
from .model_scalar_creator_rule_v1 import ModelScalarCreatorRuleV1
from .model_table_application_output_v1 import ModelTableApplicationOutputV1
from .model_table_applications_output_list_v1 import ModelTableApplicationsOutputListV1
from .model_table_applications_output_v1 import ModelTableApplicationsOutputV1
from .model_v1 import ModelV1
from .monitor_definition_output_v1 import MonitorDefinitionOutputV1
from .monitor_definitions_output_v1 import MonitorDefinitionsOutputV1
from .monitor_input_v1 import MonitorInputV1
from .monitor_output_v1 import MonitorOutputV1
from .monitor_values import MonitorValues
from .monitored_condition_output_list_v1 import MonitoredConditionOutputListV1
from .monitored_condition_output_v1 import MonitoredConditionOutputV1
from .monitored_signal_last_run_state_output_v1 import MonitoredSignalLastRunStateOutputV1
from .monitored_signal_output_list_v1 import MonitoredSignalOutputListV1
from .monitored_signal_output_v1 import MonitoredSignalOutputV1
from .monitors_output_v1 import MonitorsOutputV1
from .notifiable_report_output_list_v1 import NotifiableReportOutputListV1
from .notifiable_report_output_v1 import NotifiableReportOutputV1
from .notification_configuration_output_v1 import NotificationConfigurationOutputV1
from .numeric_description_input_v1 import NumericDescriptionInputV1
from .numeric_description_output_list_v1 import NumericDescriptionOutputListV1
from .numeric_description_output_v1 import NumericDescriptionOutputV1
from .optional_report_input_v1 import OptionalReportInputV1
from .order_by_input_v1 import OrderByInputV1
from .organization_input_v1 import OrganizationInputV1
from .organization_output_v1 import OrganizationOutputV1
from .parameter_doc_output_v1 import ParameterDocOutputV1
from .password_reset_input import PasswordResetInput
from .permissions_v1 import PermissionsV1
from .plugin_output_list_v1 import PluginOutputListV1
from .plugin_output_v1 import PluginOutputV1
from .plugins_body import PluginsBody
from .pre_cached_condition_capsule_property_info_v1 import PreCachedConditionCapsulePropertyInfoV1
from .pre_provision_input_v1 import PreProvisionInputV1
from .pre_provision_output_v1 import PreProvisionOutputV1
from .precached_item_output_v1 import PrecachedItemOutputV1
from .precached_items_output_v1 import PrecachedItemsOutputV1
from .priority_v1 import PriorityV1
from .progress_information_output_v1 import ProgressInformationOutputV1
from .project_input_v1 import ProjectInputV1
from .project_output_v1 import ProjectOutputV1
from .properties_for_item_uuid_column import PropertiesForItemUUIDColumn
from .properties_for_item_uuid_column_input_v1 import PropertiesForItemUUIDColumnInputV1
from .property_filter_input_v1 import PropertyFilterInputV1
from .property_href_output_v1 import PropertyHrefOutputV1
from .property_input_v1 import PropertyInputV1
from .property_output_v1 import PropertyOutputV1
from .property_search_v1 import PropertySearchV1
from .provision_input_v1 import ProvisionInputV1
from .publish_events_input_v1 import PublishEventsInputV1
from .publish_events_output_v1 import PublishEventsOutputV1
from .put_asset_input_v1 import PutAssetInputV1
from .put_scalar_input_v1 import PutScalarInputV1
from .put_scalars_input_v1 import PutScalarsInputV1
from .put_signals_input_v1 import PutSignalsInputV1
from .put_user_groups_input_v1 import PutUserGroupsInputV1
from .radial_gauge_rehydration_instructions_input_v1 import RadialGaugeRehydrationInstructionsInputV1
from .radial_gauge_rehydration_instructions_output_v1 import RadialGaugeRehydrationInstructionsOutputV1
from .radial_rehydration_instructions_input_v1 import RadialRehydrationInstructionsInputV1
from .radial_rehydration_instructions_output_v1 import RadialRehydrationInstructionsOutputV1
from .recompute_table_input_v1 import RecomputeTableInputV1
from .recompute_table_output_v1 import RecomputeTableOutputV1
from .referenced_input_item_v1 import ReferencedInputItemV1
from .referenced_items_output_v1 import ReferencedItemsOutputV1
from .referenced_output_item_v1 import ReferencedOutputItemV1
from .referenced_table_definition_ids_output_v1 import ReferencedTableDefinitionIdsOutputV1
from .regex_config_field_v1 import RegexConfigFieldV1
from .regression_output_v1 import RegressionOutputV1
from .rehydration_instructions_input_v1 import RehydrationInstructionsInputV1
from .rehydration_instructions_output_v1 import RehydrationInstructionsOutputV1
from .rehydration_series_lookup_input_v1 import RehydrationSeriesLookupInputV1
from .rehydration_series_lookup_output_v1 import RehydrationSeriesLookupOutputV1
from .release_notes_output_v1 import ReleaseNotesOutputV1
from .remote_agent_directives_output_v1 import RemoteAgentDirectivesOutputV1
from .remote_agent_status_input_v1 import RemoteAgentStatusInputV1
from .remote_agent_status_output_v1 import RemoteAgentStatusOutputV1
from .report_input_item_v1 import ReportInputItemV1
from .report_input_v1 import ReportInputV1
from .report_notification_configuration_input_v1 import ReportNotificationConfigurationInputV1
from .report_template_input_v1 import ReportTemplateInputV1
from .report_template_output_v1 import ReportTemplateOutputV1
from .request_output_v1 import RequestOutputV1
from .request_password_reset_input import RequestPasswordResetInput
from .row_event_input_v1 import RowEventInputV1
from .row_id import RowId
from .row_id_input_list_v1 import RowIdInputListV1
from .row_id_input_v1 import RowIdInputV1
from .row_rules_result_v1 import RowRulesResultV1
from .rules_result_message_v1 import RulesResultMessageV1
from .rules_result_v1 import RulesResultV1
from .run_condition_monitor_job_input_v1 import RunConditionMonitorJobInputV1
from .sample_input_v1 import SampleInputV1
from .sample_output_v1 import SampleOutputV1
from .samples_input_v1 import SamplesInputV1
from .samples_output_v1 import SamplesOutputV1
from .samples_overwrite_input_v1 import SamplesOverwriteInputV1
from .scalar_evaluate_output_v1 import ScalarEvaluateOutputV1
from .scalar_input_v1 import ScalarInputV1
from .scalar_property_v1 import ScalarPropertyV1
from .scalar_value_output_v1 import ScalarValueOutputV1
from .scale_across_tree_output_v1 import ScaleAcrossTreeOutputV1
from .scaling_table_uuid_column_search_v1 import ScalingTableUUIDColumnSearchV1
from .schedulable_admin_list_output_v1 import SchedulableAdminListOutputV1
from .schedulable_admin_output_v1 import SchedulableAdminOutputV1
from .schedulable_summary_day_output_v1 import SchedulableSummaryDayOutputV1
from .schedulable_summary_week_output_v1 import SchedulableSummaryWeekOutputV1
from .schedulable_workbook_output_v1 import SchedulableWorkbookOutputV1
from .schedule_input_v1 import ScheduleInputV1
from .schedule_output_v1 import ScheduleOutputV1
from .scheduled_notebook_input_v1 import ScheduledNotebookInputV1
from .scheduled_notebook_list_output_v1 import ScheduledNotebookListOutputV1
from .scheduled_notebook_output_v1 import ScheduledNotebookOutputV1
from .scheduled_notebook_result_input_v1 import ScheduledNotebookResultInputV1
from .scim_token_input_v1 import ScimTokenInputV1
from .scim_token_output_v1 import ScimTokenOutputV1
from .screenshot_output_v1 import ScreenshotOutputV1
from .secret_config_field_v1 import SecretConfigFieldV1
from .secret_status import SecretStatus
from .see_also_doc_output_v1 import SeeAlsoDocOutputV1
from .send_email_attachment_v1 import SendEmailAttachmentV1
from .send_email_contact_v1 import SendEmailContactV1
from .send_email_input_v1 import SendEmailInputV1
from .sent_email_attachment_output_v1 import SentEmailAttachmentOutputV1
from .sent_email_output_v1 import SentEmailOutputV1
from .sent_emails_list_output_v1 import SentEmailsListOutputV1
from .server_build_info_output_v1 import ServerBuildInfoOutputV1
from .server_load_output_v1 import ServerLoadOutputV1
from .server_spec_output_v1 import ServerSpecOutputV1
from .server_status_output_v1 import ServerStatusOutputV1
from .set_trust_input_v1 import SetTrustInputV1
from .shared_columns_output_v1 import SharedColumnsOutputV1
from .shared_item_information import SharedItemInformation
from .signal_input_v1 import SignalInputV1
from .signal_monitor_input_v1 import SignalMonitorInputV1
from .signal_monitor_metadata_output_list_v1 import SignalMonitorMetadataOutputListV1
from .signal_monitor_metadata_output_v1 import SignalMonitorMetadataOutputV1
from .signal_monitor_output_v1 import SignalMonitorOutputV1
from .signal_monitor_workbook_output_v1 import SignalMonitorWorkbookOutputV1
from .signal_output_v1 import SignalOutputV1
from .signal_with_id_input_v1 import SignalWithIdInputV1
from .simple_filter import SimpleFilter
from .sort import Sort
from .status_message import StatusMessage
from .status_message_base import StatusMessageBase
from .store_secret_input_v1 import StoreSecretInputV1
from .stored_table_csv_input_v1 import StoredTableCSVInputV1
from .stored_table_column_input_v1 import StoredTableColumnInputV1
from .stored_table_column_output_v1 import StoredTableColumnOutputV1
from .stored_table_delete_rows_input_v1 import StoredTableDeleteRowsInputV1
from .stored_table_output_v1 import StoredTableOutputV1
from .stored_table_search_failure_output_list_v1 import StoredTableSearchFailureOutputListV1
from .stored_table_search_failure_output_v1 import StoredTableSearchFailureOutputV1
from .stored_table_search_v1 import StoredTableSearchV1
from .storedtables_csv_body import StoredtablesCsvBody
from .string_config_field_v1 import StringConfigFieldV1
from .subscription_input_v1 import SubscriptionInputV1
from .subscription_output_v1 import SubscriptionOutputV1
from .subscription_update_input_v1 import SubscriptionUpdateInputV1
from .support_request_input_v1 import SupportRequestInputV1
from .support_request_output_v1 import SupportRequestOutputV1
from .supported_units_output_v1 import SupportedUnitsOutputV1
from .suppress_condition_input_v1 import SuppressConditionInputV1
from .suppressed_condition_input_v1 import SuppressedConditionInputV1
from .suppressed_condition_output_v1 import SuppressedConditionOutputV1
from .swap_across_assets_search_v1 import SwapAcrossAssetsSearchV1
from .swap_input_v1 import SwapInputV1
from .swap_option_list_v1 import SwapOptionListV1
from .swap_option_v1 import SwapOptionV1
from .swap_output_v1 import SwapOutputV1
from .sync_progress import SyncProgress
from .sync_progress_output_v1 import SyncProgressOutputV1
from .system_license_body import SystemLicenseBody
from .table_application_retired_output_v1 import TableApplicationRetiredOutputV1
from .table_column_output_v1 import TableColumnOutputV1
from .table_compute_output_v1 import TableComputeOutputV1
from .table_data_query_input_v1 import TableDataQueryInputV1
from .table_definition_csv_input_v1 import TableDefinitionCSVInputV1
from .table_definition_csv_publish_rows_input_v1 import TableDefinitionCSVPublishRowsInputV1
from .table_definition_csv_publish_rows_output_v1 import TableDefinitionCSVPublishRowsOutputV1
from .table_definition_csv_update_input_v1 import TableDefinitionCSVUpdateInputV1
from .table_definition_input_v1 import TableDefinitionInputV1
from .table_definition_output_list_v1 import TableDefinitionOutputListV1
from .table_definition_output_v1 import TableDefinitionOutputV1
from .table_definition_preview_input_v1 import TableDefinitionPreviewInputV1
from .table_definition_preview_output_v1 import TableDefinitionPreviewOutputV1
from .table_definition_update_input_v1 import TableDefinitionUpdateInputV1
from .table_formula import TableFormula
from .table_join_input import TableJoinInput
from .table_model_application_input_v1 import TableModelApplicationInputV1
from .table_property_filter_input_v1 import TablePropertyFilterInputV1
from .table_property_input_v1 import TablePropertyInputV1
from .table_result_output_v1 import TableResultOutputV1
from .tabledefinitions_csv_body import TabledefinitionsCsvBody
from .threshold_metric_input_v1 import ThresholdMetricInputV1
from .threshold_metric_output_v1 import ThresholdMetricOutputV1
from .threshold_output_v1 import ThresholdOutputV1
from .tile_create_input_v1 import TileCreateInputV1
from .tile_layout_output_v1 import TileLayoutOutputV1
from .tile_output_v1 import TileOutputV1
from .tile_update_input_v1 import TileUpdateInputV1
from .time_interval import TimeInterval
from .timer_datum_v1 import TimerDatumV1
from .topic_sandbox_input_v1 import TopicSandboxInputV1
from .tree_item_output_v1 import TreeItemOutputV1
from .treemap_item_output_v1 import TreemapItemOutputV1
from .treemap_output_v1 import TreemapOutputV1
from .units_of_measure_batch_input_v1 import UnitsOfMeasureBatchInputV1
from .units_of_measure_item_v1 import UnitsOfMeasureItemV1
from .units_of_measure_output_v1 import UnitsOfMeasureOutputV1
from .unsubscribe_output_v1 import UnsubscribeOutputV1
from .updated_rows_output_v1 import UpdatedRowsOutputV1
from .usage_output_list_v1 import UsageOutputListV1
from .usage_output_v1 import UsageOutputV1
from .usage_types_v1 import UsageTypesV1
from .user_group_input_v1 import UserGroupInputV1
from .user_group_output_v1 import UserGroupOutputV1
from .user_group_with_id_input_v1 import UserGroupWithIdInputV1
from .user_input_v1 import UserInputV1
from .user_output_list_v1 import UserOutputListV1
from .user_output_v1 import UserOutputV1
from .user_password_input_v1 import UserPasswordInputV1
from .validate_cron_list_input_v1 import ValidateCronListInputV1
from .validate_cron_list_output_v1 import ValidateCronListOutputV1
from .validate_cron_output_v1 import ValidateCronOutputV1
from .value import Value
from .value_filter import ValueFilter
from .version_history_output_list_v1 import VersionHistoryOutputListV1
from .version_history_output_v1 import VersionHistoryOutputV1
from .version_input_v1 import VersionInputV1
from .version_output_v1 import VersionOutputV1
from .version_source_item_output_v1 import VersionSourceItemOutputV1
from .version_source_output_v1 import VersionSourceOutputV1
from .view_column_filter_input_v1 import ViewColumnFilterInputV1
from .view_column_filter_output_v1 import ViewColumnFilterOutputV1
from .view_column_input_v1 import ViewColumnInputV1
from .view_column_output_v1 import ViewColumnOutputV1
from .virtual_columns import VirtualColumns
from .workbench_item_output_list_v1 import WorkbenchItemOutputListV1
from .workbench_search_result_preview_v1 import WorkbenchSearchResultPreviewV1
from .workbook_input_v1 import WorkbookInputV1
from .workbook_output_list_v1 import WorkbookOutputListV1
from .workbook_output_v1 import WorkbookOutputV1
from .workbook_owner_output_v1 import WorkbookOwnerOutputV1
from .worksheet_input_v1 import WorksheetInputV1
from .worksheet_output_list_v1 import WorksheetOutputListV1
from .worksheet_output_v1 import WorksheetOutputV1
from .workstep_chronology_entry_v1 import WorkstepChronologyEntryV1
from .workstep_chronology_output_v1 import WorkstepChronologyOutputV1
from .workstep_input_v1 import WorkstepInputV1
from .workstep_output_v1 import WorkstepOutputV1



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class PropertySearchV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ancestor_id': 'str',
        'folder_id': 'str',
        'is_include': 'bool',
        'predicates': 'list[PropertyFilterInputV1]',
        'search_order': 'int',
        'search_type': 'str',
        'types': 'list[str]'
    }

    attribute_map = {
        'ancestor_id': 'ancestorId',
        'folder_id': 'folderId',
        'is_include': 'isInclude',
        'predicates': 'predicates',
        'search_order': 'searchOrder',
        'search_type': 'searchType',
        'types': 'types'
    }

    def __init__(self, ancestor_id=None, folder_id=None, is_include=None, predicates=None, search_order=None, search_type=None, types=None):
        """
        PropertySearchV1 - a model defined in Swagger
        """

        self._ancestor_id = None
        self._folder_id = None
        self._is_include = None
        self._predicates = None
        self._search_order = None
        self._search_type = None
        self._types = None

        if ancestor_id is not None:
          self.ancestor_id = ancestor_id
        if folder_id is not None:
          self.folder_id = folder_id
        if is_include is not None:
          self.is_include = is_include
        if predicates is not None:
          self.predicates = predicates
        if search_order is not None:
          self.search_order = search_order
        if search_type is not None:
          self.search_type = search_type
        if types is not None:
          self.types = types

    @property
    def ancestor_id(self):
        """
        Gets the ancestor_id of this PropertySearchV1.
        If provided, only search for items that are descendants of this asset

        :return: The ancestor_id of this PropertySearchV1.
        :rtype: str
        """
        return self._ancestor_id

    @ancestor_id.setter
    def ancestor_id(self, ancestor_id):
        """
        Sets the ancestor_id of this PropertySearchV1.
        If provided, only search for items that are descendants of this asset

        :param ancestor_id: The ancestor_id of this PropertySearchV1.
        :type: str
        """

        self._ancestor_id = ancestor_id

    @property
    def folder_id(self):
        """
        Gets the folder_id of this PropertySearchV1.
        If provided, only search for items that are scoped to the workbooks contained in this folder

        :return: The folder_id of this PropertySearchV1.
        :rtype: str
        """
        return self._folder_id

    @folder_id.setter
    def folder_id(self, folder_id):
        """
        Sets the folder_id of this PropertySearchV1.
        If provided, only search for items that are scoped to the workbooks contained in this folder

        :param folder_id: The folder_id of this PropertySearchV1.
        :type: str
        """

        self._folder_id = folder_id

    @property
    def is_include(self):
        """
        Gets the is_include of this PropertySearchV1.
        If true, the items found by this search will be included in the output. If false, then the results will be excluded from the output (even if found by another search)

        :return: The is_include of this PropertySearchV1.
        :rtype: bool
        """
        return self._is_include

    @is_include.setter
    def is_include(self, is_include):
        """
        Sets the is_include of this PropertySearchV1.
        If true, the items found by this search will be included in the output. If false, then the results will be excluded from the output (even if found by another search)

        :param is_include: The is_include of this PropertySearchV1.
        :type: bool
        """
        if is_include is None:
            raise ValueError("Invalid value for `is_include`, must not be `None`")

        self._is_include = is_include

    @property
    def predicates(self):
        """
        Gets the predicates of this PropertySearchV1.
        A list of predicates by which to filter the items

        :return: The predicates of this PropertySearchV1.
        :rtype: list[PropertyFilterInputV1]
        """
        return self._predicates

    @predicates.setter
    def predicates(self, predicates):
        """
        Sets the predicates of this PropertySearchV1.
        A list of predicates by which to filter the items

        :param predicates: The predicates of this PropertySearchV1.
        :type: list[PropertyFilterInputV1]
        """

        self._predicates = predicates

    @property
    def search_order(self):
        """
        Gets the search_order of this PropertySearchV1.
        The order in which this search should be executed. When the same item appears in multiple searches, the search with the highest order value wins. If not specified, searches are ordered by their creation time (UUID).

        :return: The search_order of this PropertySearchV1.
        :rtype: int
        """
        return self._search_order

    @search_order.setter
    def search_order(self, search_order):
        """
        Sets the search_order of this PropertySearchV1.
        The order in which this search should be executed. When the same item appears in multiple searches, the search with the highest order value wins. If not specified, searches are ordered by their creation time (UUID).

        :param search_order: The search_order of this PropertySearchV1.
        :type: int
        """

        self._search_order = search_order

    @property
    def search_type(self):
        """
        Gets the search_type of this PropertySearchV1.
        The type of search

        :return: The search_type of this PropertySearchV1.
        :rtype: str
        """
        return self._search_type

    @search_type.setter
    def search_type(self, search_type):
        """
        Sets the search_type of this PropertySearchV1.
        The type of search

        :param search_type: The search_type of this PropertySearchV1.
        :type: str
        """
        if search_type is None:
            raise ValueError("Invalid value for `search_type`, must not be `None`")

        self._search_type = search_type

    @property
    def types(self):
        """
        Gets the types of this PropertySearchV1.
        A list of types by which to filter the items

        :return: The types of this PropertySearchV1.
        :rtype: list[str]
        """
        return self._types

    @types.setter
    def types(self, types):
        """
        Sets the types of this PropertySearchV1.
        A list of types by which to filter the items

        :param types: The types of this PropertySearchV1.
        :type: list[str]
        """
        if types is None:
            raise ValueError("Invalid value for `types`, must not be `None`")

        self._types = types

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PropertySearchV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class TableDefinitionCSVUpdateInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_delimiter': 'str',
        'header_row': 'int',
        'name': 'str',
        'upload_filename': 'str'
    }

    attribute_map = {
        'column_delimiter': 'columnDelimiter',
        'header_row': 'headerRow',
        'name': 'name',
        'upload_filename': 'uploadFilename'
    }

    def __init__(self, column_delimiter=None, header_row=None, name=None, upload_filename=None):
        """
        TableDefinitionCSVUpdateInputV1 - a model defined in Swagger
        """

        self._column_delimiter = None
        self._header_row = None
        self._name = None
        self._upload_filename = None

        if column_delimiter is not None:
          self.column_delimiter = column_delimiter
        if header_row is not None:
          self.header_row = header_row
        if name is not None:
          self.name = name
        if upload_filename is not None:
          self.upload_filename = upload_filename

    @property
    def column_delimiter(self):
        """
        Gets the column_delimiter of this TableDefinitionCSVUpdateInputV1.
        The character used as the CSV field delimiter. The possibilities are comma, semicolon, and tab

        :return: The column_delimiter of this TableDefinitionCSVUpdateInputV1.
        :rtype: str
        """
        return self._column_delimiter

    @column_delimiter.setter
    def column_delimiter(self, column_delimiter):
        """
        Sets the column_delimiter of this TableDefinitionCSVUpdateInputV1.
        The character used as the CSV field delimiter. The possibilities are comma, semicolon, and tab

        :param column_delimiter: The column_delimiter of this TableDefinitionCSVUpdateInputV1.
        :type: str
        """
        if column_delimiter is None:
            raise ValueError("Invalid value for `column_delimiter`, must not be `None`")

        self._column_delimiter = column_delimiter

    @property
    def header_row(self):
        """
        Gets the header_row of this TableDefinitionCSVUpdateInputV1.
        Index of row with unique column headers to be used in the creation of table-definition columns. The row index is 1-based.

        :return: The header_row of this TableDefinitionCSVUpdateInputV1.
        :rtype: int
        """
        return self._header_row

    @header_row.setter
    def header_row(self, header_row):
        """
        Sets the header_row of this TableDefinitionCSVUpdateInputV1.
        Index of row with unique column headers to be used in the creation of table-definition columns. The row index is 1-based.

        :param header_row: The header_row of this TableDefinitionCSVUpdateInputV1.
        :type: int
        """
        if header_row is None:
            raise ValueError("Invalid value for `header_row`, must not be `None`")

        self._header_row = header_row

    @property
    def name(self):
        """
        Gets the name of this TableDefinitionCSVUpdateInputV1.
        Human readable name of the table. An input of just whitespaces is equivalent to a null input.

        :return: The name of this TableDefinitionCSVUpdateInputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TableDefinitionCSVUpdateInputV1.
        Human readable name of the table. An input of just whitespaces is equivalent to a null input.

        :param name: The name of this TableDefinitionCSVUpdateInputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def upload_filename(self):
        """
        Gets the upload_filename of this TableDefinitionCSVUpdateInputV1.
        The server-side name of the CSV file that is returned from the upload endpoint.

        :return: The upload_filename of this TableDefinitionCSVUpdateInputV1.
        :rtype: str
        """
        return self._upload_filename

    @upload_filename.setter
    def upload_filename(self, upload_filename):
        """
        Sets the upload_filename of this TableDefinitionCSVUpdateInputV1.
        The server-side name of the CSV file that is returned from the upload endpoint.

        :param upload_filename: The upload_filename of this TableDefinitionCSVUpdateInputV1.
        :type: str
        """
        if upload_filename is None:
            raise ValueError("Invalid value for `upload_filename`, must not be `None`")

        self._upload_filename = upload_filename

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TableDefinitionCSVUpdateInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class HierarchyNodeWithPathOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'hierarchy_id': 'str',
        'hierarchy_name': 'str',
        'node': 'HierarchyNodeOutputV1',
        'path': 'list[HierarchyNodeOutputV1]'
    }

    attribute_map = {
        'hierarchy_id': 'hierarchyId',
        'hierarchy_name': 'hierarchyName',
        'node': 'node',
        'path': 'path'
    }

    def __init__(self, hierarchy_id=None, hierarchy_name=None, node=None, path=None):
        """
        HierarchyNodeWithPathOutputV1 - a model defined in Swagger
        """

        self._hierarchy_id = None
        self._hierarchy_name = None
        self._node = None
        self._path = None

        if hierarchy_id is not None:
          self.hierarchy_id = hierarchy_id
        if hierarchy_name is not None:
          self.hierarchy_name = hierarchy_name
        if node is not None:
          self.node = node
        if path is not None:
          self.path = path

    @property
    def hierarchy_id(self):
        """
        Gets the hierarchy_id of this HierarchyNodeWithPathOutputV1.
        The id of the hierarchy the node is from

        :return: The hierarchy_id of this HierarchyNodeWithPathOutputV1.
        :rtype: str
        """
        return self._hierarchy_id

    @hierarchy_id.setter
    def hierarchy_id(self, hierarchy_id):
        """
        Sets the hierarchy_id of this HierarchyNodeWithPathOutputV1.
        The id of the hierarchy the node is from

        :param hierarchy_id: The hierarchy_id of this HierarchyNodeWithPathOutputV1.
        :type: str
        """
        if hierarchy_id is None:
            raise ValueError("Invalid value for `hierarchy_id`, must not be `None`")

        self._hierarchy_id = hierarchy_id

    @property
    def hierarchy_name(self):
        """
        Gets the hierarchy_name of this HierarchyNodeWithPathOutputV1.
        The name of the hierarchy the node is from

        :return: The hierarchy_name of this HierarchyNodeWithPathOutputV1.
        :rtype: str
        """
        return self._hierarchy_name

    @hierarchy_name.setter
    def hierarchy_name(self, hierarchy_name):
        """
        Sets the hierarchy_name of this HierarchyNodeWithPathOutputV1.
        The name of the hierarchy the node is from

        :param hierarchy_name: The hierarchy_name of this HierarchyNodeWithPathOutputV1.
        :type: str
        """
        if hierarchy_name is None:
            raise ValueError("Invalid value for `hierarchy_name`, must not be `None`")

        self._hierarchy_name = hierarchy_name

    @property
    def node(self):
        """
        Gets the node of this HierarchyNodeWithPathOutputV1.

        :return: The node of this HierarchyNodeWithPathOutputV1.
        :rtype: HierarchyNodeOutputV1
        """
        return self._node

    @node.setter
    def node(self, node):
        """
        Sets the node of this HierarchyNodeWithPathOutputV1.

        :param node: The node of this HierarchyNodeWithPathOutputV1.
        :type: HierarchyNodeOutputV1
        """
        if node is None:
            raise ValueError("Invalid value for `node`, must not be `None`")

        self._node = node

    @property
    def path(self):
        """
        Gets the path of this HierarchyNodeWithPathOutputV1.
        The hierarchy nodes in the path of the node in the hierarchy, exclusive.

        :return: The path of this HierarchyNodeWithPathOutputV1.
        :rtype: list[HierarchyNodeOutputV1]
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this HierarchyNodeWithPathOutputV1.
        The hierarchy nodes in the path of the node in the hierarchy, exclusive.

        :param path: The path of this HierarchyNodeWithPathOutputV1.
        :type: list[HierarchyNodeOutputV1]
        """
        if path is None:
            raise ValueError("Invalid value for `path`, must not be `None`")

        self._path = path

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, HierarchyNodeWithPathOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
